# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clinvar_data/pbs/clinvar_public.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%clinvar_data/pbs/clinvar_public.proto\x12\x1f\x63linvar_data.pbs.clinvar_public\x1a\x1fgoogle/protobuf/timestamp.proto"\x8c\x01\n\x07\x43omment\x12\r\n\x05value\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x61ta_source\x18\x02 \x01(\tH\x00\x88\x01\x01\x12?\n\x04type\x18\x03 \x01(\x0e\x32,.clinvar_data.pbs.clinvar_public.CommentTypeH\x01\x88\x01\x01\x42\x0e\n\x0c_data_sourceB\x07\n\x05_type"\x9d\x01\n\x04Xref\x12\n\n\x02\x64\x62\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\x04type\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x04 \x01(\tH\x01\x88\x01\x01\x12<\n\x06status\x18\x05 \x01(\x0e\x32\'.clinvar_data.pbs.clinvar_public.StatusH\x02\x88\x01\x01\x42\x07\n\x05_typeB\x06\n\x04_urlB\t\n\x07_status"\xf6\x01\n\x08\x43itation\x12=\n\x03ids\x18\x01 \x03(\x0b\x32\x30.clinvar_data.pbs.clinvar_public.Citation.IdType\x12\x10\n\x03url\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rcitation_text\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04type\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x13\n\x06\x61\x62\x62rev\x18\x05 \x01(\tH\x03\x88\x01\x01\x1a\'\n\x06IdType\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0e\n\x06source\x18\x02 \x01(\tB\x06\n\x04_urlB\x10\n\x0e_citation_textB\x07\n\x05_typeB\t\n\x07_abbrev"\x9f\x01\n\rBaseAttribute\x12\x12\n\x05value\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rinteger_value\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x33\n\ndate_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x42\x08\n\x06_valueB\x10\n\x0e_integer_valueB\r\n\x0b_date_value"\x91\x04\n\x18HgvsNucleotideExpression\x12\x12\n\nexpression\x18\x01 \x01(\t\x12O\n\rsequence_type\x18\x02 \x01(\x0e\x32\x33.clinvar_data.pbs.clinvar_public.NucleotideSequenceH\x00\x88\x01\x01\x12\'\n\x1asequence_accession_version\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1f\n\x12sequence_accession\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x10sequence_version\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12\x13\n\x06\x63hange\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08\x61ssembly\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tsubmitted\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x18\n\x0bmane_select\x18\t \x01(\x08H\x07\x88\x01\x01\x12\x1f\n\x12mane_plus_clinical\x18\n \x01(\x08H\x08\x88\x01\x01\x42\x10\n\x0e_sequence_typeB\x1d\n\x1b_sequence_accession_versionB\x15\n\x13_sequence_accessionB\x13\n\x11_sequence_versionB\t\n\x07_changeB\x0b\n\t_assemblyB\x0c\n\n_submittedB\x0e\n\x0c_mane_selectB\x15\n\x13_mane_plus_clinical"\xff\x01\n\x15HgvsProteinExpression\x12\x12\n\nexpression\x18\x01 \x01(\t\x12\'\n\x1asequence_accession_version\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x12sequence_accession\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10sequence_version\x18\x04 \x01(\x05H\x02\x88\x01\x01\x12\x13\n\x06\x63hange\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x1d\n\x1b_sequence_accession_versionB\x15\n\x13_sequence_accessionB\x13\n\x11_sequence_versionB\t\n\x07_change"\x9d\x03\n\x0eHgvsExpression\x12]\n\x15nucleotide_expression\x18\x01 \x01(\x0b\x32\x39.clinvar_data.pbs.clinvar_public.HgvsNucleotideExpressionH\x00\x88\x01\x01\x12W\n\x12protein_expression\x18\x02 \x01(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.HgvsProteinExpressionH\x01\x88\x01\x01\x12\x45\n\x16molecular_consequences\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12\x37\n\x04type\x18\x04 \x01(\x0e\x32).clinvar_data.pbs.clinvar_public.HgvsType\x12\x15\n\x08\x61ssembly\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x18\n\x16_nucleotide_expressionB\x15\n\x13_protein_expressionB\x0b\n\t_assembly"\\\n\x08Software\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x07version\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07purpose\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\n\n\x08_versionB\n\n\x08_purpose"c\n\x12\x44\x65scriptionHistory\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12.\n\x05\x64\x61ted\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x42\x08\n\x06_dated"\xe0\x01\n\x11GenericSetElement\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12<\n\tcitations\x18\x03 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x05 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment"\xf1\x02\n\x13\x41ttributeSetElement\x12Q\n\tattribute\x18\x01 \x01(\x0b\x32>.clinvar_data.pbs.clinvar_public.AttributeSetElement.Attribute\x12\x34\n\x05xrefs\x18\x02 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x03 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x04 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x1aW\n\tAttribute\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.BaseAttribute\x12\x0c\n\x04type\x18\x02 \x01(\t"\xff\x07\n\x05Trait\x12\x41\n\x05names\x18\x01 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12\x43\n\x07symbols\x18\x02 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12H\n\nattributes\x18\x03 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12U\n\x13trait_relationships\x18\x04 \x03(\x0b\x32\x38.clinvar_data.pbs.clinvar_public.Trait.TraitRelationship\x12<\n\tcitations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x06 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x07 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x0f\n\x07sources\x18\x08 \x03(\t\x1a\x8b\x04\n\x11TraitRelationship\x12\x41\n\x05names\x18\x01 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12<\n\tcitations\x18\x02 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x04 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x0f\n\x07sources\x18\x05 \x03(\t\x12K\n\x04type\x18\x06 \x01(\x0e\x32=.clinvar_data.pbs.clinvar_public.Trait.TraitRelationship.Type"\xa4\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x12\n\x0eTYPE_PHENOTYPE\x10\x01\x12\x15\n\x11TYPE_SUBPHENOTYPE\x10\x02\x12"\n\x1eTYPE_DRUG_RESPONSE_AND_DISEASE\x10\x03\x12\x1e\n\x1aTYPE_CO_OCCURING_CONDITION\x10\x04\x12\x17\n\x13TYPE_FINDING_MEMBER\x10\x05"\xf4\x03\n\nIndication\x12\x36\n\x06traits\x18\x01 \x03(\x0b\x32&.clinvar_data.pbs.clinvar_public.Trait\x12\x41\n\x05names\x18\x02 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12H\n\nattributes\x18\x03 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x06 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12>\n\x04type\x18\x07 \x01(\x0e\x32\x30.clinvar_data.pbs.clinvar_public.Indication.Type"1\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fTYPE_INDICATION\x10\x01"\xf6\x07\n\x08TraitSet\x12\x36\n\x06traits\x18\x01 \x03(\x0b\x32&.clinvar_data.pbs.clinvar_public.Trait\x12\x41\n\x05names\x18\x02 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12\x43\n\x07symbols\x18\x03 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.GenericSetElement\x12H\n\nattributes\x18\x04 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12\x34\n\x05xrefs\x18\x05 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x06 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x07 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12<\n\x04type\x18\x08 \x01(\x0e\x32..clinvar_data.pbs.clinvar_public.TraitSet.Type\x12<\n\x13\x64\x61te_last_evaluated\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\n \x01(\x03H\x01\x88\x01\x01\x12\x34\n\'contributes_to_aggregate_classification\x18\x0b \x01(\x08H\x02\x88\x01\x01\x12$\n\x17lower_level_of_evidence\x18\x0c \x01(\x08H\x03\x88\x01\x01\x12+\n\x1emultiple_condition_explanation\x18\r \x01(\tH\x04\x88\x01\x01"\x8f\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_DISEASE\x10\x01\x12\x16\n\x12TYPE_DRUG_RESPONSE\x10\x02\x12\x10\n\x0cTYPE_FINDING\x10\x03\x12\x1e\n\x1aTYPE_PHENOTYPE_INSTRUCTION\x10\x04\x12\x15\n\x11TYPE_TRAIT_CHOICE\x10\x05\x42\x16\n\x14_date_last_evaluatedB\x05\n\x03_idB*\n(_contributes_to_aggregate_classificationB\x1a\n\x18_lower_level_of_evidenceB!\n\x1f_multiple_condition_explanation"\xf2\x06\n AggregatedGermlineClassification\x12U\n\rreview_status\x18\x01 \x01(\x0e\x32>.clinvar_data.pbs.clinvar_public.AggregateGermlineReviewStatus\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x42\n\x0b\x65xplanation\x18\x03 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentH\x01\x88\x01\x01\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x06 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12L\n\x0fhistory_records\x18\x07 \x03(\x0b\x32\x33.clinvar_data.pbs.clinvar_public.DescriptionHistory\x12=\n\nconditions\x18\x08 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.TraitSet\x12<\n\x13\x64\x61te_last_evaluated\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x12\x30\n\x0c\x64\x61te_created\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16most_recent_submission\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x14number_of_submitters\x18\x0c \x01(\x05H\x03\x88\x01\x01\x12"\n\x15number_of_submissions\x18\r \x01(\x05H\x04\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0e\n\x0c_explanationB\x16\n\x14_date_last_evaluatedB\x17\n\x15_number_of_submittersB\x18\n\x16_number_of_submissions"\xaa\x06\n\x1f\x41ggregatedSomaticClinicalImpact\x12\x62\n\rreview_status\x18\x01 \x01(\x0e\x32K.clinvar_data.pbs.clinvar_public.AggregateSomaticClinicalImpactReviewStatus\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x34\n\x05xrefs\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x04 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x05 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12L\n\x0fhistory_records\x18\x06 \x03(\x0b\x32\x33.clinvar_data.pbs.clinvar_public.DescriptionHistory\x12=\n\nconditions\x18\x07 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.TraitSet\x12<\n\x13\x64\x61te_last_evaluated\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x30\n\x0c\x64\x61te_created\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16most_recent_submission\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x14number_of_submitters\x18\x0b \x01(\x05H\x02\x88\x01\x01\x12"\n\x15number_of_submissions\x18\x0c \x01(\x05H\x03\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x16\n\x14_date_last_evaluatedB\x17\n\x15_number_of_submittersB\x18\n\x16_number_of_submissions"\xa6\x06\n$AggregatedOncogenicityClassification\x12Y\n\rreview_status\x18\x01 \x01(\x0e\x32\x42.clinvar_data.pbs.clinvar_public.AggregateOncogenicityReviewStatus\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x34\n\x05xrefs\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x04 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x05 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12L\n\x0fhistory_records\x18\x06 \x03(\x0b\x32\x33.clinvar_data.pbs.clinvar_public.DescriptionHistory\x12=\n\nconditions\x18\x07 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.TraitSet\x12<\n\x13\x64\x61te_last_evaluated\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x12\x30\n\x0c\x64\x61te_created\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16most_recent_submission\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\x14number_of_submitters\x18\x0b \x01(\x05H\x02\x88\x01\x01\x12"\n\x15number_of_submissions\x18\x0c \x01(\x05H\x03\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x16\n\x14_date_last_evaluatedB\x17\n\x15_number_of_submittersB\x18\n\x16_number_of_submissions"\xb6\x03\n\x1a\x41ggregateClassificationSet\x12g\n\x17germline_classification\x18\x01 \x01(\x0b\x32\x41.clinvar_data.pbs.clinvar_public.AggregatedGermlineClassificationH\x00\x88\x01\x01\x12\x66\n\x17somatic_clinical_impact\x18\x02 \x01(\x0b\x32@.clinvar_data.pbs.clinvar_public.AggregatedSomaticClinicalImpactH\x01\x88\x01\x01\x12o\n\x1boncogenicity_classification\x18\x03 \x01(\x0b\x32\x45.clinvar_data.pbs.clinvar_public.AggregatedOncogenicityClassificationH\x02\x88\x01\x01\x42\x1a\n\x18_germline_classificationB\x1a\n\x18_somatic_clinical_impactB\x1e\n\x1c_oncogenicity_classification"\x80\x04\n\x14\x43linicalSignificance\x12R\n\rreview_status\x18\x01 \x01(\x0e\x32\x36.clinvar_data.pbs.clinvar_public.SubmitterReviewStatusH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x42\n\x0b\x65xplanation\x18\x03 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentH\x02\x88\x01\x01\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x06 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12<\n\x13\x64\x61te_last_evaluated\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x03\x88\x01\x01\x42\x10\n\x0e_review_statusB\x0e\n\x0c_descriptionB\x0e\n\x0c_explanationB\x16\n\x14_date_last_evaluated"\x87\x04\n\x11\x41lleleDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12i\n\x14relative_orientation\x18\x02 \x01(\x0e\x32\x46.clinvar_data.pbs.clinvar_public.AlleleDescription.RelativeOrientationH\x00\x88\x01\x01\x12@\n\x08zygosity\x18\x03 \x01(\x0e\x32).clinvar_data.pbs.clinvar_public.ZygosityH\x01\x88\x01\x01\x12Y\n\x15\x63linical_significance\x18\x04 \x01(\x0b\x32\x35.clinvar_data.pbs.clinvar_public.ClinicalSignificanceH\x02\x88\x01\x01"\x9b\x01\n\x13RelativeOrientation\x12$\n RELATIVE_ORIENTATION_UNSPECIFIED\x10\x00\x12\x1c\n\x18RELATIVE_ORIENTATION_CIS\x10\x01\x12\x1e\n\x1aRELATIVE_ORIENTATION_TRANS\x10\x02\x12 \n\x1cRELATIVE_ORIENTATION_UNKNOWN\x10\x03\x42\x17\n\x15_relative_orientationB\x0b\n\t_zygosityB\x18\n\x16_clinical_significance"\xdd\x01\n\rRecordHistory\x12>\n\x07\x63omment\x18\x01 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentH\x00\x88\x01\x01\x12\x11\n\taccession\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x30\n\x0c\x64\x61te_changed\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x0cvariation_id\x18\x05 \x01(\x03H\x01\x88\x01\x01\x42\n\n\x08_commentB\x0f\n\r_variation_id"\x9e\t\n\x11\x43lassificationScv\x12M\n\rreview_status\x18\x01 \x01(\x0e\x32\x36.clinvar_data.pbs.clinvar_public.SubmitterReviewStatus\x12$\n\x17germline_classification\x18\x02 \x01(\tH\x00\x88\x01\x01\x12n\n\x17somatic_clinical_impact\x18\x03 \x01(\x0b\x32H.clinvar_data.pbs.clinvar_public.ClassificationScv.SomaticClinicalImpactH\x01\x88\x01\x01\x12(\n\x1boncogenicity_classification\x18\x04 \x01(\tH\x02\x88\x01\x01\x12*\n\x1d\x65xplanation_of_classification\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x65\n\x15\x63lassification_scores\x18\x06 \x03(\x0b\x32\x46.clinvar_data.pbs.clinvar_public.ClassificationScv.ClassificationScore\x12\x34\n\x05xrefs\x18\x07 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x08 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\t \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12<\n\x13\x64\x61te_last_evaluated\x18\n \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x04\x88\x01\x01\x1a\xa4\x02\n\x15SomaticClinicalImpact\x12\r\n\x05value\x18\x01 \x01(\t\x12+\n\x1e\x63linical_impact_assertion_type\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x32\n%clinical_impact_clinical_significance\x18\x03 \x01(\tH\x01\x88\x01\x01\x12+\n\x1e\x64rug_for_therapeutic_assertion\x18\x04 \x01(\tH\x02\x88\x01\x01\x42!\n\x1f_clinical_impact_assertion_typeB(\n&_clinical_impact_clinical_significanceB!\n\x1f_drug_for_therapeutic_assertion\x1a@\n\x13\x43lassificationScore\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x11\n\x04type\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_typeB\x1a\n\x18_germline_classificationB\x1a\n\x18_somatic_clinical_impactB\x1e\n\x1c_oncogenicity_classificationB \n\x1e_explanation_of_classificationB\x16\n\x14_date_last_evaluated"\x88\x01\n\x14SubmitterIdentifiers\x12\x16\n\x0esubmitter_name\x18\x01 \x01(\t\x12\x0e\n\x06org_id\x18\x02 \x01(\x03\x12\x14\n\x0corg_category\x18\x03 \x01(\t\x12\x1d\n\x10org_abbreviation\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x13\n\x11_org_abbreviation"A\n\x07Species\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0btaxonomy_id\x18\x02 \x01(\x05H\x00\x88\x01\x01\x42\x0e\n\x0c_taxonomy_id"T\n\x13\x43lassifiedCondition\x12\r\n\x05value\x18\x01 \x01(\t\x12\x0f\n\x02\x64\x62\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x02id\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_dbB\x05\n\x03_id"\xd3\x01\n\x1e\x43linicalAssertionRecordHistory\x12>\n\x07\x63omment\x18\x01 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentH\x00\x88\x01\x01\x12\x11\n\taccession\x18\x02 \x01(\t\x12\x14\n\x07version\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x30\n\x0c\x64\x61te_changed\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\n\x08_commentB\n\n\x08_version"\xd6\x01\n\x15\x46unctionalConsequence\x12\x34\n\x05xrefs\x18\x01 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x02 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x03 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\r\n\x05value\x18\x04 \x01(\t"\x86\x01\n\x10GeneralCitations\x12\x34\n\x05xrefs\x18\x01 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x02 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation"\xcc\x01\n\x0c\x43ooccurrence\x12@\n\x08zygosity\x18\x01 \x01(\x0e\x32).clinvar_data.pbs.clinvar_public.ZygosityH\x00\x88\x01\x01\x12O\n\x13\x61llele_descriptions\x18\x02 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.AlleleDescription\x12\x12\n\x05\x63ount\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\x0b\n\t_zygosityB\x08\n\x06_count"\xf5\x01\n\tSubmitter\x12T\n\x15submitter_identifiers\x18\x01 \x01(\x0b\x32\x35.clinvar_data.pbs.clinvar_public.SubmitterIdentifiers\x12=\n\x04type\x18\x02 \x01(\x0e\x32/.clinvar_data.pbs.clinvar_public.Submitter.Type"S\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_PRIMARY\x10\x01\x12\x12\n\x0eTYPE_SECONDARY\x10\x02\x12\x0f\n\x0bTYPE_BEHALF\x10\x03"\x90\x01\n\x11\x44osageSensitivity\x12\r\n\x05value\x18\x01 \x01(\t\x12\x37\n\x0elast_evaluated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x14\n\x07\x63lingen\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x11\n\x0f_last_evaluatedB\n\n\x08_clingen"6\n\tOtherName\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\x04type\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_type"b\n\nDeletedScv\x12\x11\n\taccession\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x30\n\x0c\x64\x61te_deleted\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\xff\n\n\x08Location\x12\x1d\n\x15\x63ytogenetic_locations\x18\x01 \x03(\t\x12V\n\x12sequence_locations\x18\x02 \x03(\x0b\x32:.clinvar_data.pbs.clinvar_public.Location.SequenceLocation\x12\x16\n\x0egene_locations\x18\x03 \x03(\t\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x1a\xad\t\n\x10SequenceLocation\x12\x18\n\x0b\x66or_display\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x10\n\x08\x61ssembly\x18\x02 \x01(\t\x12\x38\n\x03\x63hr\x18\x03 \x01(\x0e\x32+.clinvar_data.pbs.clinvar_public.Chromosome\x12\x16\n\taccession\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0bouter_start\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\x18\n\x0binner_start\x18\x06 \x01(\rH\x03\x88\x01\x01\x12\x12\n\x05start\x18\x07 \x01(\rH\x04\x88\x01\x01\x12\x11\n\x04stop\x18\x08 \x01(\rH\x05\x88\x01\x01\x12\x17\n\ninner_stop\x18\t \x01(\rH\x06\x88\x01\x01\x12\x17\n\nouter_stop\x18\n \x01(\rH\x07\x88\x01\x01\x12\x1a\n\rdisplay_start\x18\x0b \x01(\rH\x08\x88\x01\x01\x12\x19\n\x0c\x64isplay_stop\x18\x0c \x01(\rH\t\x88\x01\x01\x12\x13\n\x06strand\x18\r \x01(\tH\n\x88\x01\x01\x12\x1b\n\x0evariant_length\x18\x0e \x01(\rH\x0b\x88\x01\x01\x12\x1d\n\x10reference_allele\x18\x0f \x01(\tH\x0c\x88\x01\x01\x12\x1d\n\x10\x61lternate_allele\x18\x10 \x01(\tH\r\x88\x01\x01\x12\'\n\x1a\x61ssembly_accession_version\x18\x11 \x01(\tH\x0e\x88\x01\x01\x12g\n\x0f\x61ssembly_status\x18\x12 \x01(\x0e\x32I.clinvar_data.pbs.clinvar_public.Location.SequenceLocation.AssemblyStatusH\x0f\x88\x01\x01\x12\x19\n\x0cposition_vcf\x18\x13 \x01(\rH\x10\x88\x01\x01\x12!\n\x14reference_allele_vcf\x18\x14 \x01(\tH\x11\x88\x01\x01\x12!\n\x14\x61lternate_allele_vcf\x18\x15 \x01(\tH\x12\x88\x01\x01\x12\x1f\n\x12\x66or_display_length\x18\x16 \x01(\rH\x13\x88\x01\x01"l\n\x0e\x41ssemblyStatus\x12\x1f\n\x1b\x41SSEMBLY_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x41SSEMBLY_STATUS_CURRENT\x10\x01\x12\x1c\n\x18\x41SSEMBLY_STATUS_PREVIOUS\x10\x02\x42\x0e\n\x0c_for_displayB\x0c\n\n_accessionB\x0e\n\x0c_outer_startB\x0e\n\x0c_inner_startB\x08\n\x06_startB\x07\n\x05_stopB\r\n\x0b_inner_stopB\r\n\x0b_outer_stopB\x10\n\x0e_display_startB\x0f\n\r_display_stopB\t\n\x07_strandB\x11\n\x0f_variant_lengthB\x13\n\x11_reference_alleleB\x13\n\x11_alternate_alleleB\x1d\n\x1b_assembly_accession_versionB\x12\n\x10_assembly_statusB\x0f\n\r_position_vcfB\x17\n\x15_reference_allele_vcfB\x17\n\x15_alternate_allele_vcfB\x15\n\x13_for_display_length"G\n\x03Scv\x12\x12\n\x05title\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\taccession\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x42\x08\n\x06_title"\xf4\x02\n\nFamilyData\x12\x1b\n\x0e\x66\x61mily_history\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cnum_families\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12&\n\x19num_families_with_variant\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x33\n&num_families_with_segregation_observed\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x18\n\x0bpedigree_id\x18\x05 \x01(\tH\x04\x88\x01\x01\x12!\n\x14segregation_observed\x18\x06 \x01(\tH\x05\x88\x01\x01\x42\x11\n\x0f_family_historyB\x0f\n\r_num_familiesB\x1c\n\x1a_num_families_with_variantB)\n\'_num_families_with_segregation_observedB\x0e\n\x0c_pedigree_idB\x17\n\x15_segregation_observed"\xa0\x16\n\x06Sample\x12Z\n\x12sample_description\x18\x01 \x01(\x0b\x32\x39.clinvar_data.pbs.clinvar_public.Sample.SampleDescriptionH\x00\x88\x01\x01\x12<\n\x06origin\x18\x02 \x01(\x0e\x32\'.clinvar_data.pbs.clinvar_public.OriginH\x01\x88\x01\x01\x12\x16\n\tethnicity\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1e\n\x11geographic_origin\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06tissue\x18\x05 \x01(\tH\x04\x88\x01\x01\x12s\n somatic_variant_in_normal_tissue\x18\x06 \x01(\x0e\x32\x44.clinvar_data.pbs.clinvar_public.Sample.SomaticVariantInNormalTissueH\x05\x88\x01\x01\x12,\n\x1fsomatic_variant_allele_fraction\x18\x07 \x01(\tH\x06\x88\x01\x01\x12\x16\n\tcell_line\x18\x08 \x01(\tH\x07\x88\x01\x01\x12>\n\x07species\x18\t \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.SpeciesH\x08\x88\x01\x01\x12\x39\n\x04\x61ges\x18\n \x03(\x0b\x32+.clinvar_data.pbs.clinvar_public.Sample.Age\x12\x13\n\x06strain\x18\x0b \x01(\tH\t\x88\x01\x01\x12T\n\x0f\x61\x66\x66\x65\x63ted_status\x18\x0c \x01(\x0e\x32\x36.clinvar_data.pbs.clinvar_public.Sample.AffectedStatusH\n\x88\x01\x01\x12\x19\n\x0cnumer_tested\x18\r \x01(\x05H\x0b\x88\x01\x01\x12\x19\n\x0cnumber_males\x18\x0e \x01(\x05H\x0c\x88\x01\x01\x12\x1b\n\x0enumber_females\x18\x0f \x01(\x05H\r\x88\x01\x01\x12\x1e\n\x11number_chr_tested\x18\x10 \x01(\x05H\x0e\x88\x01\x01\x12\x43\n\x06gender\x18\x11 \x01(\x0e\x32..clinvar_data.pbs.clinvar_public.Sample.GenderH\x0f\x88\x01\x01\x12\x45\n\x0b\x66\x61mily_data\x18\x12 \x01(\x0b\x32+.clinvar_data.pbs.clinvar_public.FamilyDataH\x10\x88\x01\x01\x12\x14\n\x07proband\x18\x13 \x01(\tH\x11\x88\x01\x01\x12\x44\n\nindication\x18\x14 \x01(\x0b\x32+.clinvar_data.pbs.clinvar_public.IndicationH\x12\x88\x01\x01\x12<\n\tcitations\x18\x15 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x16 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x17 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12L\n\x0bsource_type\x18\x18 \x01(\x0e\x32\x32.clinvar_data.pbs.clinvar_public.Sample.SourceTypeH\x13\x88\x01\x01\x1a\xb6\x01\n\x11SampleDescription\x12\x42\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentH\x00\x88\x01\x01\x12@\n\x08\x63itation\x18\x02 \x01(\x0b\x32).clinvar_data.pbs.clinvar_public.CitationH\x01\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0b\n\t_citation\x1a\x92\x01\n\x03\x41ge\x12\r\n\x05value\x18\x01 \x01(\x05\x12=\n\x04unit\x18\x02 \x01(\x0e\x32/.clinvar_data.pbs.clinvar_public.Sample.AgeUnit\x12=\n\x04type\x18\x03 \x01(\x0e\x32/.clinvar_data.pbs.clinvar_public.Sample.AgeType"\xdc\x01\n\x1cSomaticVariantInNormalTissue\x12\x30\n,SOMATIC_VARIANT_IN_NORMAL_TISSUE_UNSPECIFIED\x10\x00\x12,\n(SOMATIC_VARIANT_IN_NORMAL_TISSUE_PRESENT\x10\x01\x12+\n\'SOMATIC_VARIANT_IN_NORMAL_TISSUE_ABSENT\x10\x02\x12/\n+SOMATIC_VARIANT_IN_NORMAL_TISSUE_NOT_TESTED\x10\x03"\xb0\x01\n\x07\x41geUnit\x12\x18\n\x14\x41GE_UNIT_UNSPECIFIED\x10\x00\x12\x11\n\rAGE_UNIT_DAYS\x10\x01\x12\x12\n\x0e\x41GE_UNIT_WEEKS\x10\x02\x12\x13\n\x0f\x41GE_UNIT_MONTHS\x10\x03\x12\x12\n\x0e\x41GE_UNIT_YEARS\x10\x04\x12\x1c\n\x18\x41GE_UNIT_WEEKS_GESTATION\x10\x05\x12\x1d\n\x19\x41GE_UNIT_MONTHS_GESTATION\x10\x06"d\n\x07\x41geType\x12\x18\n\x14\x41GE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41GE_TYPE_MINIMUM\x10\x01\x12\x14\n\x10\x41GE_TYPE_MAXIMUM\x10\x02\x12\x13\n\x0f\x41GE_TYPE_SINGLE\x10\x03"\xc5\x01\n\x0e\x41\x66\x66\x65\x63tedStatus\x12\x1f\n\x1b\x41\x46\x46\x45\x43TED_STATUS_UNSPECIFIED\x10\x00\x12\x17\n\x13\x41\x46\x46\x45\x43TED_STATUS_YES\x10\x01\x12\x16\n\x12\x41\x46\x46\x45\x43TED_STATUS_NO\x10\x02\x12 \n\x1c\x41\x46\x46\x45\x43TED_STATUS_NOT_PROVIDED\x10\x03\x12\x1b\n\x17\x41\x46\x46\x45\x43TED_STATUS_UNKNOWN\x10\x04\x12"\n\x1e\x41\x46\x46\x45\x43TED_STATUS_NOT_APPLICABLE\x10\x05"V\n\x06Gender\x12\x16\n\x12GENDER_UNSPECIFIED\x10\x00\x12\x0f\n\x0bGENDER_MALE\x10\x01\x12\x11\n\rGENDER_FEMALE\x10\x02\x12\x10\n\x0cGENDER_MIXED\x10\x03"k\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12#\n\x1fSOURCE_TYPE_SUBMITTER_GENERATED\x10\x01\x12\x1b\n\x17SOURCE_TYPE_DATA_MINING\x10\x02\x42\x15\n\x13_sample_descriptionB\t\n\x07_originB\x0c\n\n_ethnicityB\x14\n\x12_geographic_originB\t\n\x07_tissueB#\n!_somatic_variant_in_normal_tissueB"\n _somatic_variant_allele_fractionB\x0c\n\n_cell_lineB\n\n\x08_speciesB\t\n\x07_strainB\x12\n\x10_affected_statusB\x0f\n\r_numer_testedB\x0f\n\r_number_malesB\x11\n\x0f_number_femalesB\x14\n\x12_number_chr_testedB\t\n\x07_genderB\x0e\n\x0c_family_dataB\n\n\x08_probandB\r\n\x0b_indicationB\x0e\n\x0c_source_type"\xe9\x0f\n\x06Method\x12\x1a\n\rname_platform\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rtype_platform\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07purpose\x18\x03 \x01(\tH\x02\x88\x01\x01\x12L\n\x0bresult_type\x18\x04 \x01(\x0e\x32\x32.clinvar_data.pbs.clinvar_public.Method.ResultTypeH\x03\x88\x01\x01\x12\x19\n\x0cmin_reported\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x19\n\x0cmax_reported\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1f\n\x12reference_standard\x18\x07 \x01(\tH\x06\x88\x01\x01\x12<\n\tcitations\x18\x08 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\t \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12\x18\n\x0b\x64\x65scription\x18\n \x01(\tH\x07\x88\x01\x01\x12;\n\x08software\x18\x0b \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Software\x12L\n\x0bsource_type\x18\x0c \x01(\x0e\x32\x32.clinvar_data.pbs.clinvar_public.Method.SourceTypeH\x08\x88\x01\x01\x12\x44\n\x0bmethod_type\x18\r \x01(\x0e\x32/.clinvar_data.pbs.clinvar_public.MethodListType\x12R\n\x11method_attributes\x18\x0e \x03(\x0b\x32\x37.clinvar_data.pbs.clinvar_public.Method.MethodAttribute\x12Y\n\x15obs_method_attributes\x18\x0f \x03(\x0b\x32:.clinvar_data.pbs.clinvar_public.Method.ObsMethodAttribute\x1a\xb0\x03\n\x0fMethodAttribute\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.BaseAttribute\x12S\n\x04type\x18\x02 \x01(\x0e\x32\x45.clinvar_data.pbs.clinvar_public.Method.MethodAttribute.AttributeType"\x89\x02\n\rAttributeType\x12\x1e\n\x1a\x41TTRIBUTE_TYPE_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x41TTRIBUTE_TYPE_LOCATION\x10\x01\x12\'\n#ATTRIBUTE_TYPE_CONTROLS_APPROPRIATE\x10\x02\x12%\n!ATTRIBUTE_TYPE_METHOD_APPROPRIATE\x10\x03\x12\x1c\n\x18\x41TTRIBUTE_TYPE_TEST_NAME\x10\x04\x12)\n%ATTRIBUTE_TYPE_STRUCT_VAR_METHOD_TYPE\x10\x05\x12"\n\x1e\x41TTRIBUTE_TYPE_PROBE_ACCESSION\x10\x06\x1a\xe0\x02\n\x12ObsMethodAttribute\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.BaseAttribute\x12V\n\x04type\x18\x02 \x01(\x0e\x32H.clinvar_data.pbs.clinvar_public.Method.ObsMethodAttribute.AttributeType\x12:\n\x08\x63omments\x18\x03 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment"x\n\rAttributeType\x12\x1e\n\x1a\x41TTRIBUTE_TYPE_UNSPECIFIED\x10\x00\x12 \n\x1c\x41TTRIBUTE_TYPE_METHOD_RESULT\x10\x01\x12%\n!ATTRIBUTE_TYPE_TESTING_LABORATORY\x10\x02"\xa3\x01\n\nResultType\x12\x1b\n\x17RESULT_TYPE_UNSPECIFIED\x10\x00\x12%\n!RESULT_TYPE_NUMBER_OF_OCCURRENCES\x10\x01\x12\x17\n\x13RESULT_TYPE_P_VALUE\x10\x02\x12\x1a\n\x16RESULT_TYPE_ODDS_RATIO\x10\x03\x12\x1c\n\x18RESULT_TYPE_VARIANT_CALL\x10\x04"\x88\x01\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12#\n\x1fSOURCE_TYPE_SUBMITTER_GENERATED\x10\x01\x12\x1b\n\x17SOURCE_TYPE_DATA_MINING\x10\x02\x12\x1b\n\x17SOURCE_TYPE_DATA_REVIEW\x10\x03\x42\x10\n\x0e_name_platformB\x10\n\x0e_type_platformB\n\n\x08_purposeB\x0e\n\x0c_result_typeB\x0f\n\r_min_reportedB\x0f\n\r_max_reportedB\x15\n\x13_reference_standardB\x0e\n\x0c_descriptionB\x0e\n\x0c_source_type"\xe0\n\n\tAlleleScv\x12>\n\x05genes\x18\x01 \x03(\x0b\x32/.clinvar_data.pbs.clinvar_public.AlleleScv.Gene\x12\x38\n\x04name\x18\x02 \x01(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12\x19\n\x0cvariant_type\x18\x03 \x01(\tH\x00\x88\x01\x01\x12@\n\x08location\x18\x04 \x01(\x0b\x32).clinvar_data.pbs.clinvar_public.LocationH\x01\x88\x01\x01\x12?\n\x0bother_names\x18\x05 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12\x17\n\x0fprotein_changes\x18\x06 \x03(\t\x12\x34\n\x05xrefs\x18\x07 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x08 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\t \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12_\n\x16molecular_consequences\x18\n \x03(\x0b\x32?.clinvar_data.pbs.clinvar_public.AlleleScv.MolecularConsequence\x12W\n\x17\x66unctional_consequences\x18\x0b \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12H\n\nattributes\x18\x0c \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12\x16\n\tallele_id\x18\r \x01(\x03H\x02\x88\x01\x01\x1a\xfc\x01\n\x04Gene\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\nproperties\x18\x02 \x03(\t\x12\x34\n\x05xrefs\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12\x13\n\x06symbol\x18\x04 \x01(\tH\x01\x88\x01\x01\x12X\n\x11relationship_type\x18\x05 \x01(\x0e\x32\x38.clinvar_data.pbs.clinvar_public.GeneVariantRelationshipH\x02\x88\x01\x01\x42\x07\n\x05_nameB\t\n\x07_symbolB\x14\n\x12_relationship_type\x1a\xaa\x02\n\x14MolecularConsequence\x12\x34\n\x05xrefs\x18\x01 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x02 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x03 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x0f\n\x02rs\x18\x04 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04hgvs\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05so_id\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x10\n\x08\x66unction\x18\x07 \x01(\tB\x05\n\x03_rsB\x07\n\x05_hgvsB\x08\n\x06_so_idB\x0f\n\r_variant_typeB\x0b\n\t_locationB\x0c\n\n_allele_id"\x8f\x06\n\x0cHaplotypeScv\x12\x42\n\x0esimple_alleles\x18\x01 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.AlleleScv\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12?\n\x0bother_names\x18\x03 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12Y\n\x0f\x63lassifications\x18\x04 \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSetH\x01\x88\x01\x01\x12W\n\x17\x66unctional_consequences\x18\x05 \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12H\n\nattributes\x18\x06 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12<\n\tcitations\x18\x07 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x08 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\t \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x19\n\x0cvariation_id\x18\n \x01(\x03H\x02\x88\x01\x01\x12\x1d\n\x10number_of_copies\x18\x0b \x01(\x05H\x03\x88\x01\x01\x12"\n\x15number_of_chromosomes\x18\x0c \x01(\x05H\x04\x88\x01\x01\x42\x07\n\x05_nameB\x12\n\x10_classificationsB\x0f\n\r_variation_idB\x13\n\x11_number_of_copiesB\x18\n\x16_number_of_chromosomes"\xb8\x05\n\x0bGenotypeScv\x12\x42\n\x0esimple_alleles\x18\x01 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.AlleleScv\x12\x41\n\nhaplotypes\x18\x02 \x03(\x0b\x32-.clinvar_data.pbs.clinvar_public.HaplotypeScv\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x12?\n\x0bother_names\x18\x04 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12\x46\n\x0evariation_type\x18\x05 \x01(\x0e\x32..clinvar_data.pbs.clinvar_public.VariationType\x12W\n\x17\x66unctional_consequences\x18\x06 \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12H\n\nattributes\x18\x07 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12<\n\tcitations\x18\x08 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\t \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\n \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x19\n\x0cvariation_id\x18\x0b \x01(\x03H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x0f\n\r_variation_id"\xe4\x10\n\nObservedIn\x12\x37\n\x06sample\x18\x01 \x01(\x0b\x32\'.clinvar_data.pbs.clinvar_public.Sample\x12O\n\robserved_data\x18\x02 \x03(\x0b\x32\x38.clinvar_data.pbs.clinvar_public.ObservedIn.ObservedData\x12H\n\x11\x63ooccurrence_sets\x18\x03 \x03(\x0b\x32-.clinvar_data.pbs.clinvar_public.Cooccurrence\x12\x41\n\ttrait_set\x18\x04 \x01(\x0b\x32).clinvar_data.pbs.clinvar_public.TraitSetH\x00\x88\x01\x01\x12<\n\tcitations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x06 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x07 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x1a\xf3\x07\n\x15ObservedDataAttribute\x12<\n\x04\x62\x61se\x18\x01 \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.BaseAttribute\x12T\n\x04type\x18\x02 \x01(\x0e\x32\x46.clinvar_data.pbs.clinvar_public.ObservedIn.ObservedDataAttribute.Type"\xc5\x06\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10TYPE_DESCRIPTION\x10\x01\x12\x18\n\x14TYPE_VARIANT_ALLELES\x10\x02\x12\x1e\n\x1aTYPE_SUBJECTS_WITH_VARIANT\x10\x03\x12\x32\n.TYPE_SUBJECTS_WITH_DIFFERENT_CAUSATIVE_VARIANT\x10\x04\x12\x1c\n\x18TYPE_VARIANT_CHROMOSOMES\x10\x05\x12!\n\x1dTYPE_INDEPENDENT_OBSERVATIONS\x10\x06\x12\x1c\n\x18TYPE_SINGLE_HETEROZYGOUS\x10\x07\x12\x1e\n\x1aTYPE_COMPOUND_HETEROZYGOUS\x10\x08\x12\x13\n\x0fTYPE_HOMOZYGOUS\x10\t\x12\x13\n\x0fTYPE_HEMIZYGOUS\x10\n\x12\x16\n\x12TYPE_NUMBER_MOSAIC\x10\x0b\x12\x1d\n\x19TYPE_OBSERVED_UNSPECIFIED\x10\x0c\x12\x19\n\x15TYPE_ALLELE_FREQUENCY\x10\r\x12\x1a\n\x16TYPE_SECONDARY_FINDING\x10\x0e\x12$\n TYPE_GENOTYPE_AND_MOI_CONSISTENT\x10\x0f\x12\x38\n4TYPE_UNAFFECTED_FAMILY_MEMBER_WITH_CAUSATIVE_VARIANT\x10\x10\x12*\n&TYPE_HET_PARENT_TRANSMIT_NORMAL_ALLELE\x10\x11\x12\x1f\n\x1bTYPE_COSEGREGATING_FAMILIES\x10\x12\x12\x1c\n\x18TYPE_INFORMATIVE_MEIOSES\x10\x13\x12\x18\n\x14TYPE_SAMPLE_LOCAL_ID\x10\x14\x12\x1a\n\x16TYPE_SAMPLE_VARIANT_ID\x10\x15\x12\x17\n\x13TYPE_FAMILY_HISTORY\x10\x16\x12"\n\x1eTYPE_NUM_FAMILIES_WITH_VARIANT\x10\x17\x12/\n+TYPE_NUM_FAMILIES_WITH_SEGREGATION_OBSERVED\x10\x18\x12\x1d\n\x19TYPE_SEGREGATION_OBSERVED\x10\x19\x1a\xe4\x02\n\x0cObservedData\x12U\n\nattributes\x18\x01 \x03(\x0b\x32\x41.clinvar_data.pbs.clinvar_public.ObservedIn.ObservedDataAttribute\x12@\n\x08severity\x18\x02 \x01(\x0e\x32).clinvar_data.pbs.clinvar_public.SeverityH\x00\x88\x01\x01\x12<\n\tcitations\x18\x03 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x34\n\x05xrefs\x18\x04 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x05 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.CommentB\x0b\n\t_severity"\xa3\x02\n\nMethodType\x12\x1b\n\x17METHOD_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bMETHOD_TYPE_LITERATURE_ONLY\x10\x01\x12$\n METHOD_TYPE_REFERENCE_POPULATION\x10\x02\x12\x1c\n\x18METHOD_TYPE_CASE_CONTROL\x10\x03\x12 \n\x1cMETHOD_TYPE_CLINICAL_TESTING\x10\x04\x12\x18\n\x14METHOD_TYPE_IN_VITRO\x10\x05\x12\x17\n\x13METHOD_TYPE_IN_VIVO\x10\x06\x12$\n METHOD_TYPE_INFERRED_FROM_SOURCE\x10\x07\x12\x18\n\x14METHOD_TYPE_RESEARCH\x10\x08\x42\x0c\n\n_trait_set"\xd5\x15\n\x11\x43linicalAssertion\x12\x65\n\x15\x63linvar_submission_id\x18\x01 \x01(\x0b\x32\x46.clinvar_data.pbs.clinvar_public.ClinicalAssertion.ClinvarSubmissionId\x12^\n\x11\x63linvar_accession\x18\x02 \x01(\x0b\x32\x43.clinvar_data.pbs.clinvar_public.ClinicalAssertion.ClinvarAccession\x12I\n\x15\x61\x64\x64itional_submitters\x18\x03 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.Submitter\x12V\n\rrecord_status\x18\x04 \x01(\x0e\x32?.clinvar_data.pbs.clinvar_public.ClinicalAssertion.RecordStatus\x12\x10\n\x08replaces\x18\x05 \x03(\t\x12R\n\treplaceds\x18\x06 \x03(\x0b\x32?.clinvar_data.pbs.clinvar_public.ClinicalAssertionRecordHistory\x12K\n\x0f\x63lassifications\x18\x07 \x01(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.ClassificationScv\x12=\n\tassertion\x18\x08 \x01(\x0e\x32*.clinvar_data.pbs.clinvar_public.Assertion\x12Z\n\nattributes\x18\t \x03(\x0b\x32\x46.clinvar_data.pbs.clinvar_public.ClinicalAssertion.AttributeSetElement\x12\x41\n\x0cobserved_ins\x18\n \x03(\x0b\x32+.clinvar_data.pbs.clinvar_public.ObservedIn\x12\x46\n\rsimple_allele\x18\x0b \x01(\x0b\x32*.clinvar_data.pbs.clinvar_public.AlleleScvH\x00\x88\x01\x01\x12\x45\n\thaplotype\x18\x0c \x01(\x0b\x32-.clinvar_data.pbs.clinvar_public.HaplotypeScvH\x01\x88\x01\x01\x12\x43\n\x08genotype\x18\r \x01(\x0b\x32,.clinvar_data.pbs.clinvar_public.GenotypeScvH\x02\x88\x01\x01\x12<\n\ttrait_set\x18\x0e \x01(\x0b\x32).clinvar_data.pbs.clinvar_public.TraitSet\x12<\n\tcitations\x18\x0f \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12\x17\n\nstudy_name\x18\x10 \x01(\tH\x03\x88\x01\x01\x12\x1e\n\x11study_description\x18\x11 \x01(\tH\x04\x88\x01\x01\x12:\n\x08\x63omments\x18\x12 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x18\n\x10submission_names\x18\x13 \x03(\t\x12\x30\n\x0c\x64\x61te_created\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11\x64\x61te_last_updated\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0fsubmission_date\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x02id\x18\x17 \x01(\x04H\x05\x88\x01\x01\x12$\n\x17\x66\x64\x61_recognized_database\x18\x18 \x01(\x08H\x06\x88\x01\x01\x1a\xbe\x01\n\x13\x43linvarSubmissionId\x12\x11\n\tlocal_key\x18\x01 \x01(\t\x12\x12\n\x05title\x18\x02 \x01(\tH\x00\x88\x01\x01\x12#\n\x16local_key_is_submitted\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x1f\n\x12submitted_assembly\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x08\n\x06_titleB\x19\n\x17_local_key_is_submittedB\x15\n\x13_submitted_assembly\x1a\xba\x04\n\x13\x41ttributeSetElement\x12\x41\n\tattribute\x18\x01 \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.BaseAttribute\x12Y\n\x04type\x18\x02 \x01(\x0e\x32K.clinvar_data.pbs.clinvar_public.ClinicalAssertion.AttributeSetElement.Type\x12\x34\n\x05xrefs\x18\x03 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\x04 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x05 \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment"\xd4\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18TYPE_MODE_OF_INHERITANCE\x10\x01\x12\x13\n\x0fTYPE_PENETRANCE\x10\x02\x12\x15\n\x11TYPE_AGE_OF_ONSET\x10\x03\x12\x11\n\rTYPE_SEVERITY\x10\x04\x12\x1f\n\x1bTYPE_CLASSIFICATION_HISTORY\x10\x05\x12\x1d\n\x19TYPE_SEVERITY_DESCRIPTION\x10\x06\x12\x19\n\x15TYPE_ASSERTION_METHOD\x10\x07\x1a\x9c\x02\n\x10\x43linvarAccession\x12\x11\n\taccession\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12T\n\x15submitter_identifiers\x18\x03 \x01(\x0b\x32\x35.clinvar_data.pbs.clinvar_public.SubmitterIdentifiers\x12\x35\n\x0c\x64\x61te_updated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x35\n\x0c\x64\x61te_created\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x01\x88\x01\x01\x42\x0f\n\r_date_updatedB\x0f\n\r_date_created"\x7f\n\x0cRecordStatus\x12\x1d\n\x19RECORD_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15RECORD_STATUS_CURRENT\x10\x01\x12\x1a\n\x16RECORD_STATUS_REPLACED\x10\x02\x12\x19\n\x15RECORD_STATUS_REMOVED\x10\x03\x42\x10\n\x0e_simple_alleleB\x0c\n\n_haplotypeB\x0b\n\t_genotypeB\r\n\x0b_study_nameB\x14\n\x12_study_descriptionB\x05\n\x03_idB\x1a\n\x18_fda_recognized_database"\xf0\r\n\x06\x41llele\x12;\n\x05genes\x18\x01 \x03(\x0b\x32,.clinvar_data.pbs.clinvar_public.Allele.Gene\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x0e\x63\x61nonical_spdi\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\rvariant_types\x18\x04 \x03(\t\x12<\n\tlocations\x18\x05 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Location\x12?\n\x0bother_names\x18\x06 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12\x17\n\x0fprotein_changes\x18\x07 \x03(\t\x12I\n\x10hgvs_expressions\x18\x08 \x03(\x0b\x32/.clinvar_data.pbs.clinvar_public.HgvsExpression\x12Y\n\x0f\x63lassifications\x18\t \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSetH\x01\x88\x01\x01\x12\x34\n\x05xrefs\x18\n \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\x0b \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12W\n\x17\x66unctional_consequences\x18\x0c \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12S\n\x12\x61llele_frequencies\x18\r \x03(\x0b\x32\x37.clinvar_data.pbs.clinvar_public.Allele.AlleleFrequency\x12n\n\x1dglobal_minor_allele_frequency\x18\x0e \x01(\x0b\x32\x42.clinvar_data.pbs.clinvar_public.Allele.GlobalMinorAlleleFrequencyH\x02\x88\x01\x01\x12\x11\n\tallele_id\x18\x0f \x01(\x03\x12\x14\n\x0cvariation_id\x18\x10 \x01(\x03\x1a\xa3\x04\n\x04Gene\x12<\n\tlocations\x18\x01 \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Location\x12\r\n\x05omims\x18\x02 \x03(\x04\x12S\n\x12haploinsufficiency\x18\x03 \x01(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.DosageSensitivityH\x00\x88\x01\x01\x12R\n\x11triplosensitivity\x18\x04 \x01(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.DosageSensitivityH\x01\x88\x01\x01\x12\x12\n\nproperties\x18\x05 \x03(\t\x12\x13\n\x06symbol\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x11\n\tfull_name\x18\x07 \x01(\t\x12\x0f\n\x07gene_id\x18\x08 \x01(\x03\x12\x14\n\x07hgnc_id\x18\t \x01(\tH\x03\x88\x01\x01\x12\x0e\n\x06source\x18\n \x01(\t\x12X\n\x11relationship_type\x18\x0b \x01(\x0e\x32\x38.clinvar_data.pbs.clinvar_public.GeneVariantRelationshipH\x04\x88\x01\x01\x42\x15\n\x13_haploinsufficiencyB\x14\n\x12_triplosensitivityB\t\n\x07_symbolB\n\n\x08_hgnc_idB\x14\n\x12_relationship_type\x1aJ\n\x0f\x41lleleFrequency\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x10\n\x03url\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x06\n\x04_url\x1a\x81\x01\n\x1aGlobalMinorAlleleFrequency\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0e\n\x06source\x18\x02 \x01(\t\x12\x19\n\x0cminor_allele\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_minor_alleleB\x06\n\x04_url\x1a\x31\n\x04Name\x12\r\n\x05value\x18\x01 \x01(\t\x12\x11\n\x04type\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_typeB\x11\n\x0f_canonical_spdiB\x12\n\x10_classificationsB \n\x1e_global_minor_allele_frequency"\xf5\x05\n\tHaplotype\x12?\n\x0esimple_alleles\x18\x01 \x03(\x0b\x32\'.clinvar_data.pbs.clinvar_public.Allele\x12\x0c\n\x04name\x18\x02 \x01(\t\x12K\n\x0evariation_type\x18\x03 \x01(\x0e\x32\x33.clinvar_data.pbs.clinvar_public.HaploVariationType\x12?\n\x0bother_names\x18\x04 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12I\n\x10hgvs_expressions\x18\x05 \x03(\x0b\x32/.clinvar_data.pbs.clinvar_public.HgvsExpression\x12Y\n\x0f\x63lassifications\x18\x06 \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSetH\x00\x88\x01\x01\x12W\n\x17\x66unctional_consequences\x18\x07 \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12\x34\n\x05xrefs\x18\x08 \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12:\n\x08\x63omments\x18\t \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x14\n\x0cvariation_id\x18\n \x01(\x03\x12\x1d\n\x10number_of_copies\x18\x0b \x01(\x05H\x01\x88\x01\x01\x12"\n\x15number_of_chromosomes\x18\x0c \x01(\x05H\x02\x88\x01\x01\x42\x12\n\x10_classificationsB\x13\n\x11_number_of_copiesB\x18\n\x16_number_of_chromosomes"\x87\x05\n\x0eIncludedRecord\x12\x43\n\rsimple_allele\x18\x01 \x01(\x0b\x32\'.clinvar_data.pbs.clinvar_public.AlleleH\x00\x88\x01\x01\x12\x42\n\thaplotype\x18\x02 \x01(\x0b\x32*.clinvar_data.pbs.clinvar_public.HaplotypeH\x01\x88\x01\x01\x12Y\n\x0f\x63lassifications\x18\x03 \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSetH\x02\x88\x01\x01\x12G\n\x19submitted_classifications\x18\x04 \x03(\x0b\x32$.clinvar_data.pbs.clinvar_public.Scv\x12\x62\n\x15\x63lassified_variations\x18\x05 \x03(\x0b\x32\x43.clinvar_data.pbs.clinvar_public.IncludedRecord.ClassifiedVariation\x12L\n\x11general_citations\x18\x06 \x03(\x0b\x32\x31.clinvar_data.pbs.clinvar_public.GeneralCitations\x1a\x62\n\x13\x43lassifiedVariation\x12\x14\n\x0cvariation_id\x18\x01 \x01(\x03\x12\x16\n\taccession\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07version\x18\x03 \x01(\x05\x42\x0c\n\n_accessionB\x10\n\x0e_simple_alleleB\x0c\n\n_haplotypeB\x12\n\x10_classifications"\xdb\x06\n\x08Genotype\x12?\n\x0esimple_alleles\x18\x01 \x03(\x0b\x32\'.clinvar_data.pbs.clinvar_public.Allele\x12>\n\nhaplotypes\x18\x02 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.Haplotype\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x46\n\x0evariation_type\x18\x04 \x01(\x0e\x32..clinvar_data.pbs.clinvar_public.VariationType\x12?\n\x0bother_names\x18\x05 \x03(\x0b\x32*.clinvar_data.pbs.clinvar_public.OtherName\x12I\n\x10hgvs_expressions\x18\x06 \x03(\x0b\x32/.clinvar_data.pbs.clinvar_public.HgvsExpression\x12W\n\x17\x66unctional_consequences\x18\x07 \x03(\x0b\x32\x36.clinvar_data.pbs.clinvar_public.FunctionalConsequence\x12Y\n\x0f\x63lassifications\x18\x08 \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSetH\x00\x88\x01\x01\x12\x34\n\x05xrefs\x18\t \x03(\x0b\x32%.clinvar_data.pbs.clinvar_public.Xref\x12<\n\tcitations\x18\n \x03(\x0b\x32).clinvar_data.pbs.clinvar_public.Citation\x12:\n\x08\x63omments\x18\x0b \x03(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12H\n\nattributes\x18\x0c \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.AttributeSetElement\x12\x19\n\x0cvariation_id\x18\r \x01(\x03H\x01\x88\x01\x01\x42\x12\n\x10_classificationsB\x0f\n\r_variation_id"\xa2\x12\n\x0cRcvAccession\x12m\n\x19\x63lassified_condition_list\x18\x01 \x01(\x0b\x32\x45.clinvar_data.pbs.clinvar_public.RcvAccession.ClassifiedConditionListH\x00\x88\x01\x01\x12]\n\x13rcv_classifications\x18\x02 \x01(\x0b\x32@.clinvar_data.pbs.clinvar_public.RcvAccession.RcvClassifications\x12\x41\n\treplaceds\x18\x03 \x03(\x0b\x32..clinvar_data.pbs.clinvar_public.RecordHistory\x12\x12\n\x05title\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x11\n\taccession\x18\x05 \x01(\t\x12\x0f\n\x07version\x18\x06 \x01(\x05\x1a\x9a\x01\n\x17\x43lassifiedConditionList\x12S\n\x15\x63lassified_conditions\x18\x01 \x03(\x0b\x32\x34.clinvar_data.pbs.clinvar_public.ClassifiedCondition\x12\x19\n\x0ctrait_set_id\x18\x02 \x01(\x03H\x00\x88\x01\x01\x42\x0f\n\r_trait_set_id\x1a\xff\x02\n\x16GermlineClassification\x12U\n\rreview_status\x18\x01 \x01(\x0e\x32>.clinvar_data.pbs.clinvar_public.AggregateGermlineReviewStatus\x12\x65\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32P.clinvar_data.pbs.clinvar_public.RcvAccession.GermlineClassification.Description\x1a\xa6\x01\n\x0b\x44\x65scription\x12\r\n\x05value\x18\x01 \x01(\t\x12<\n\x13\x64\x61te_last_evaluated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x1d\n\x10submission_count\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x16\n\x14_date_last_evaluatedB\x13\n\x11_submission_count\x1a\xb9\x04\n\x15SomaticClinicalImpact\x12\x62\n\rreview_status\x18\x01 \x01(\x0e\x32K.clinvar_data.pbs.clinvar_public.AggregateSomaticClinicalImpactReviewStatus\x12\x65\n\x0c\x64\x65scriptions\x18\x02 \x03(\x0b\x32O.clinvar_data.pbs.clinvar_public.RcvAccession.SomaticClinicalImpact.Description\x1a\xd4\x02\n\x0b\x44\x65scription\x12\r\n\x05value\x18\x01 \x01(\t\x12+\n\x1e\x63linical_impact_assertion_type\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x32\n%clinical_impact_clinical_significance\x18\x03 \x01(\tH\x01\x88\x01\x01\x12<\n\x13\x64\x61te_last_evaluated\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x02\x88\x01\x01\x12\x1d\n\x10submission_count\x18\x05 \x01(\rH\x03\x88\x01\x01\x42!\n\x1f_clinical_impact_assertion_typeB(\n&_clinical_impact_clinical_significanceB\x16\n\x14_date_last_evaluatedB\x13\n\x11_submission_count\x1a\x8b\x03\n\x1aOncogenicityClassification\x12Y\n\rreview_status\x18\x01 \x01(\x0e\x32\x42.clinvar_data.pbs.clinvar_public.AggregateOncogenicityReviewStatus\x12i\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32T.clinvar_data.pbs.clinvar_public.RcvAccession.OncogenicityClassification.Description\x1a\xa6\x01\n\x0b\x44\x65scription\x12\r\n\x05value\x18\x01 \x01(\t\x12<\n\x13\x64\x61te_last_evaluated\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x88\x01\x01\x12\x1d\n\x10submission_count\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x16\n\x14_date_last_evaluatedB\x13\n\x11_submission_count\x1a\xb7\x03\n\x12RcvClassifications\x12j\n\x17germline_classification\x18\x01 \x01(\x0b\x32\x44.clinvar_data.pbs.clinvar_public.RcvAccession.GermlineClassificationH\x00\x88\x01\x01\x12i\n\x17somatic_clinical_impact\x18\x02 \x01(\x0b\x32\x43.clinvar_data.pbs.clinvar_public.RcvAccession.SomaticClinicalImpactH\x01\x88\x01\x01\x12r\n\x1boncogenicity_classification\x18\x03 \x01(\x0b\x32H.clinvar_data.pbs.clinvar_public.RcvAccession.OncogenicityClassificationH\x02\x88\x01\x01\x42\x1a\n\x18_germline_classificationB\x1a\n\x18_somatic_clinical_impactB\x1e\n\x1c_oncogenicity_classificationB\x1c\n\x1a_classified_condition_listB\x08\n\x06_title"\xcf\n\n\x10\x43lassifiedRecord\x12\x43\n\rsimple_allele\x18\x01 \x01(\x0b\x32\'.clinvar_data.pbs.clinvar_public.AlleleH\x00\x88\x01\x01\x12\x42\n\thaplotype\x18\x02 \x01(\x0b\x32*.clinvar_data.pbs.clinvar_public.HaplotypeH\x01\x88\x01\x01\x12@\n\x08genotype\x18\x03 \x01(\x0b\x32).clinvar_data.pbs.clinvar_public.GenotypeH\x02\x88\x01\x01\x12K\n\x08rcv_list\x18\x04 \x01(\x0b\x32\x39.clinvar_data.pbs.clinvar_public.ClassifiedRecord.RcvList\x12T\n\x0f\x63lassifications\x18\x05 \x01(\x0b\x32;.clinvar_data.pbs.clinvar_public.AggregateClassificationSet\x12O\n\x13\x63linical_assertions\x18\x06 \x03(\x0b\x32\x32.clinvar_data.pbs.clinvar_public.ClinicalAssertion\x12V\n\x0etrait_mappings\x18\x07 \x03(\x0b\x32>.clinvar_data.pbs.clinvar_public.ClassifiedRecord.TraitMapping\x12\x41\n\x0c\x64\x65leted_scvs\x18\x08 \x03(\x0b\x32+.clinvar_data.pbs.clinvar_public.DeletedScv\x12L\n\x11general_citations\x18\t \x03(\x0b\x32\x31.clinvar_data.pbs.clinvar_public.GeneralCitations\x1a\xc8\x01\n\x07RcvList\x12\x45\n\x0ercv_accessions\x18\x01 \x03(\x0b\x32-.clinvar_data.pbs.clinvar_public.RcvAccession\x12\x1d\n\x10submission_count\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12%\n\x18independent_observations\x18\x03 \x01(\x05H\x01\x88\x01\x01\x42\x13\n\x11_submission_countB\x1b\n\x19_independent_observations\x1a\xbf\x02\n\x0cTraitMapping\x12V\n\x07medgens\x18\x01 \x03(\x0b\x32\x45.clinvar_data.pbs.clinvar_public.ClassifiedRecord.TraitMapping.Medgen\x12\x1d\n\x15\x63linical_assertion_id\x18\x02 \x01(\x03\x12\x12\n\ntrait_type\x18\x03 \x01(\t\x12S\n\x0cmapping_type\x18\x04 \x01(\x0e\x32=.clinvar_data.pbs.clinvar_public.ClassifiedRecord.MappingType\x12\x15\n\rmapping_value\x18\x05 \x01(\t\x12\x13\n\x0bmapping_ref\x18\x06 \x01(\t\x1a#\n\x06Medgen\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03\x63ui\x18\x02 \x01(\t"Y\n\x0bMappingType\x12\x1c\n\x18MAPPING_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11MAPPING_TYPE_NAME\x10\x01\x12\x15\n\x11MAPPING_TYPE_XREF\x10\x02\x42\x10\n\x0e_simple_alleleB\x0c\n\n_haplotypeB\x0b\n\t_genotype"\xd1\t\n\x10VariationArchive\x12\x14\n\x0cvariation_id\x18\x01 \x01(\x03\x12\x16\n\x0evariation_name\x18\x02 \x01(\t\x12\x16\n\x0evariation_type\x18\x03 \x01(\t\x12\x30\n\x0c\x64\x61te_created\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11\x64\x61te_last_updated\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12:\n\x16most_recent_submission\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\taccession\x18\x07 \x01(\t\x12\x0f\n\x07version\x18\x08 \x01(\x05\x12\x1c\n\x14number_of_submitters\x18\t \x01(\x05\x12\x1d\n\x15number_of_submissions\x18\n \x01(\x05\x12Q\n\x0brecord_type\x18\x0b \x01(\x0e\x32<.clinvar_data.pbs.clinvar_public.VariationArchive.RecordType\x12U\n\rrecord_status\x18\x0c \x01(\x0e\x32>.clinvar_data.pbs.clinvar_public.VariationArchive.RecordStatus\x12\x43\n\x0breplaced_by\x18\r \x01(\x0b\x32..clinvar_data.pbs.clinvar_public.RecordHistory\x12\x41\n\treplaceds\x18\x0e \x03(\x0b\x32..clinvar_data.pbs.clinvar_public.RecordHistory\x12\x39\n\x07\x63omment\x18\x0f \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.Comment\x12\x39\n\x07species\x18\x10 \x01(\x0b\x32(.clinvar_data.pbs.clinvar_public.Species\x12Q\n\x11\x63lassified_record\x18\x11 \x01(\x0b\x32\x31.clinvar_data.pbs.clinvar_public.ClassifiedRecordH\x00\x88\x01\x01\x12M\n\x0fincluded_record\x18\x12 \x01(\x0b\x32/.clinvar_data.pbs.clinvar_public.IncludedRecordH\x01\x88\x01\x01"_\n\nRecordType\x12\x1b\n\x17RECORD_TYPE_UNSPECIFIED\x10\x00\x12\x18\n\x14RECORD_TYPE_INCLUDED\x10\x01\x12\x1a\n\x16RECORD_TYPE_CLASSIFIED\x10\x02"\x9b\x01\n\x0cRecordStatus\x12\x1d\n\x19RECORD_STATUS_UNSPECIFIED\x10\x00\x12\x19\n\x15RECORD_STATUS_CURRENT\x10\x01\x12\x1a\n\x16RECORD_STATUS_PREVIOUS\x10\x02\x12\x1a\n\x16RECORD_STATUS_REPLACED\x10\x03\x12\x19\n\x15RECORD_STATUS_DELETED\x10\x04\x42\x14\n\x12_classified_recordB\x12\n\x10_included_record"\x9a\x01\n\x17\x43linvarVariationRelease\x12\x30\n\x0crelease_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12M\n\x12variation_archives\x18\x02 \x03(\x0b\x32\x31.clinvar_data.pbs.clinvar_public.VariationArchive*\xc2\x03\n\x17GeneVariantRelationship\x12)\n%GENE_VARIANT_RELATIONSHIP_UNSPECIFIED\x10\x00\x12\x31\n-GENE_VARIANT_RELATIONSHIP_VARIANT_WITHIN_GENE\x10\x01\x12\x38\n4GENE_VARIANT_RELATIONSHIP_GENE_OVERLAPPED_BY_VARIANT\x10\x02\x12\x30\n,GENE_VARIANT_RELATIONSHIP_NEAR_GENE_UPSTREAM\x10\x03\x12\x32\n.GENE_VARIANT_RELATIONSHIP_NEAR_GENE_DOWNSTREAM\x10\x04\x12\x37\n3GENE_VARIANT_RELATIONSHIP_ASSERTED_BUT_NOT_COMPUTED\x10\x05\x12>\n:GENE_VARIANT_RELATIONSHIP_WITHIN_MULTIPLE_GENES_BY_OVERLAP\x10\x06\x12\x30\n,GENE_VARIANT_RELATIONSHIP_WITHIN_SINGLE_GENE\x10\x07*c\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x11\n\rSEVERITY_MILD\x10\x01\x12\x15\n\x11SEVERITY_MODERATE\x10\x02\x12\x13\n\x0fSEVERITY_SEVERE\x10\x03*\xf6\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x12\n\x0eSTATUS_CURRENT\x10\x01\x12 \n\x1cSTATUS_COMPLETED_AND_RETIRED\x10\x02\x12\x11\n\rSTATUS_DELETE\x10\x03\x12\x19\n\x15STATUS_IN_DEVELOPMENT\x10\x04\x12\x17\n\x13STATUS_RECLASSIFIED\x10\x05\x12\x11\n\rSTATUS_REJECT\x10\x06\x12\x14\n\x10STATUS_SECONDARY\x10\x07\x12\x15\n\x11STATUS_SUPPRESSED\x10\x08\x12\x17\n\x13STATUS_UNDER_REVIEW\x10\t*\x97\x06\n\x15SubmitterReviewStatus\x12\'\n#SUBMITTER_REVIEW_STATUS_UNSPECIFIED\x10\x00\x12\x36\n2SUBMITTER_REVIEW_STATUS_NO_CLASSIFICATION_PROVIDED\x10\x01\x12:\n6SUBMITTER_REVIEW_STATUS_NO_ASSERTION_CRITERIA_PROVIDED\x10\x02\x12>\n:SUBMITTER_REVIEW_STATUS_CRITERIA_PROVIDED_SINGLE_SUBMITTER\x10\x03\x12\x34\n0SUBMITTER_REVIEW_STATUS_REVIEWED_BY_EXPERT_PANEL\x10\x04\x12.\n*SUBMITTER_REVIEW_STATUS_PRACTICE_GUIDELINE\x10\x05\x12.\n*SUBMITTER_REVIEW_STATUS_FLAGGED_SUBMISSION\x10\x06\x12N\nJSUBMITTER_REVIEW_STATUS_CRITERIA_PROVIDED_MULTIPLE_SUBMITTERS_NO_CONFLICTS\x10\x07\x12I\nESUBMITTER_REVIEW_STATUS_CRITERIA_PROVIDED_CONFLICTING_CLASSIFICATIONS\x10\x08\x12:\n6SUBMITTER_REVIEW_STATUS_CLASSIFIED_BY_SINGLE_SUBMITTER\x10\t\x12<\n8SUBMITTER_REVIEW_STATUS_REVIEWED_BY_PROFESSIONAL_SOCIETY\x10\n\x12\x37\n3SUBMITTER_REVIEW_STATUS_NOT_CLASSIFIED_BY_SUBMITTER\x10\x0b\x12=\n9SUBMITTER_REVIEW_STATUS_CLASSIFIED_BY_MULTIPLE_SUBMITTERS\x10\x0c*\xb7\x01\n\x08Zygosity\x12\x18\n\x14ZYGOSITY_UNSPECIFIED\x10\x00\x12\x17\n\x13ZYGOSITY_HOMOZYGOTE\x10\x01\x12 \n\x1cZYGOSITY_SINGLE_HETEROZYGOTE\x10\x02\x12"\n\x1eZYGOSITY_COMPOUND_HETEROZYGOTE\x10\x03\x12\x17\n\x13ZYGOSITY_HEMIZYGOTE\x10\x04\x12\x19\n\x15ZYGOSITY_NOT_PROVIDED\x10\x05*\x99\x02\n\tAssertion\x12\x19\n\x15\x41SSERTION_UNSPECIFIED\x10\x00\x12"\n\x1e\x41SSERTION_VARIATION_TO_DISEASE\x10\x01\x12+\n\'ASSERTION_VARIATION_TO_INCLUDED_DISEASE\x10\x02\x12\x33\n/ASSERTION_VARIATION_IN_MODIFIER_GENE_TO_DISEASE\x10\x03\x12!\n\x1d\x41SSERTION_CONFERS_SENSITIVITY\x10\x04\x12 \n\x1c\x41SSERTION_CONFERS_RESISTANCE\x10\x05\x12&\n"ASSERTION_VARIANT_TO_NAMED_PROTEIN\x10\x06*\xe4\x05\n\x1d\x41ggregateGermlineReviewStatus\x12\x30\n,AGGREGATE_GERMLINE_REVIEW_STATUS_UNSPECIFIED\x10\x00\x12?\n;AGGREGATE_GERMLINE_REVIEW_STATUS_NO_CLASSIFICATION_PROVIDED\x10\x01\x12\x43\n?AGGREGATE_GERMLINE_REVIEW_STATUS_NO_ASSERTION_CRITERIA_PROVIDED\x10\x02\x12G\nCAGGREGATE_GERMLINE_REVIEW_STATUS_CRITERIA_PROVIDED_SINGLE_SUBMITTER\x10\x03\x12W\nSAGGREGATE_GERMLINE_REVIEW_STATUS_CRITERIA_PROVIDED_MULTIPLE_SUBMITTERS_NO_CONFLICTS\x10\x04\x12R\nNAGGREGATE_GERMLINE_REVIEW_STATUS_CRITERIA_PROVIDED_CONFLICTING_CLASSIFICATIONS\x10\x05\x12=\n9AGGREGATE_GERMLINE_REVIEW_STATUS_REVIEWED_BY_EXPERT_PANEL\x10\x06\x12\x37\n3AGGREGATE_GERMLINE_REVIEW_STATUS_PRACTICE_GUIDELINE\x10\x07\x12N\nJAGGREGATE_GERMLINE_REVIEW_STATUS_NO_CLASSIFICATIONS_FROM_UNFLAGGED_RECORDS\x10\x08\x12M\nIAGGREGATE_GERMLINE_REVIEW_STATUS_NO_CLASSIFICATION_FOR_THE_SINGLE_VARIANT\x10\t*\x97\x06\n*AggregateSomaticClinicalImpactReviewStatus\x12?\n;AGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_UNSPECIFIED\x10\x00\x12N\nJAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_NO_CLASSIFICATION_PROVIDED\x10\x01\x12R\nNAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_NO_ASSERTION_CRITERIA_PROVIDED\x10\x02\x12V\nRAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_CRITERIA_PROVIDED_SINGLE_SUBMITTER\x10\x03\x12Y\nUAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_CRITERIA_PROVIDED_MULTIPLE_SUBMITTERS\x10\x04\x12L\nHAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_REVIEWED_BY_EXPERT_PANEL\x10\x05\x12\x46\nBAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_PRACTICE_GUIDELINE\x10\x06\x12]\nYAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_NO_CLASSIFICATIONS_FROM_UNFLAGGED_RECORDS\x10\x07\x12\\\nXAGGREGATE_SOMATIC_CLINICAL_IMPACT_REVIEW_STATUS_NO_CLASSIFICATION_FOR_THE_SINGLE_VARIANT\x10\x08*\x90\x06\n!AggregateOncogenicityReviewStatus\x12\x34\n0AGGREGATE_ONCOGENICITY_REVIEW_STATUS_UNSPECIFIED\x10\x00\x12\x43\n?AGGREGATE_ONCOGENICITY_REVIEW_STATUS_NO_CLASSIFICATION_PROVIDED\x10\x01\x12G\nCAGGREGATE_ONCOGENICITY_REVIEW_STATUS_NO_ASSERTION_CRITERIA_PROVIDED\x10\x02\x12K\nGAGGREGATE_ONCOGENICITY_REVIEW_STATUS_CRITERIA_PROVIDED_SINGLE_SUBMITTER\x10\x03\x12[\nWAGGREGATE_ONCOGENICITY_REVIEW_STATUS_CRITERIA_PROVIDED_MULTIPLE_SUBMITTERS_NO_CONFLICTS\x10\x04\x12V\nRAGGREGATE_ONCOGENICITY_REVIEW_STATUS_CRITERIA_PROVIDED_CONFLICTING_CLASSIFICATIONS\x10\x05\x12\x41\n=AGGREGATE_ONCOGENICITY_REVIEW_STATUS_REVIEWED_BY_EXPERT_PANEL\x10\x06\x12;\n7AGGREGATE_ONCOGENICITY_REVIEW_STATUS_PRACTICE_GUIDELINE\x10\x07\x12R\nNAGGREGATE_ONCOGENICITY_REVIEW_STATUS_NO_CLASSIFICATIONS_FROM_UNFLAGGED_RECORDS\x10\x08\x12Q\nMAGGREGATE_ONCOGENICITY_REVIEW_STATUS_NO_CLASSIFICATION_FOR_THE_SINGLE_VARIANT\x10\t*\xf2\x02\n\x06Origin\x12\x16\n\x12ORIGIN_UNSPECIFIED\x10\x00\x12\x13\n\x0fORIGIN_GERMLINE\x10\x01\x12\x12\n\x0eORIGIN_SOMATIC\x10\x02\x12\x12\n\x0eORIGIN_DE_NOVO\x10\x03\x12\x17\n\x13ORIGIN_NOT_PROVIDED\x10\x04\x12\x14\n\x10ORIGIN_INHERITED\x10\x05\x12\x13\n\x0fORIGIN_MATERNAL\x10\x06\x12\x13\n\x0fORIGIN_PATERNAL\x10\x07\x12\x16\n\x12ORIGIN_UNIPARENTAL\x10\x08\x12\x15\n\x11ORIGIN_BIPARENTAL\x10\t\x12\x17\n\x13ORIGIN_NOT_REPORTED\x10\n\x12\x1e\n\x1aORIGIN_TESTED_INCONCLUSIVE\x10\x0b\x12\x12\n\x0eORIGIN_UNKNOWN\x10\x0c\x12\x19\n\x15ORIGIN_NOT_APPLICABLE\x10\r\x12#\n\x1fORIGIN_EXPERIMENTALLY_GENERATED\x10\x0e*\x9f\x04\n\nChromosome\x12\x1a\n\x16\x43HROMOSOME_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x43HROMOSOME_1\x10\x01\x12\x10\n\x0c\x43HROMOSOME_2\x10\x02\x12\x10\n\x0c\x43HROMOSOME_3\x10\x03\x12\x10\n\x0c\x43HROMOSOME_4\x10\x04\x12\x10\n\x0c\x43HROMOSOME_5\x10\x05\x12\x10\n\x0c\x43HROMOSOME_6\x10\x06\x12\x10\n\x0c\x43HROMOSOME_7\x10\x07\x12\x10\n\x0c\x43HROMOSOME_8\x10\x08\x12\x10\n\x0c\x43HROMOSOME_9\x10\t\x12\x11\n\rCHROMOSOME_10\x10\n\x12\x11\n\rCHROMOSOME_11\x10\x0b\x12\x11\n\rCHROMOSOME_12\x10\x0c\x12\x11\n\rCHROMOSOME_13\x10\r\x12\x11\n\rCHROMOSOME_14\x10\x0e\x12\x11\n\rCHROMOSOME_15\x10\x0f\x12\x11\n\rCHROMOSOME_16\x10\x10\x12\x11\n\rCHROMOSOME_17\x10\x11\x12\x11\n\rCHROMOSOME_18\x10\x12\x12\x11\n\rCHROMOSOME_19\x10\x13\x12\x11\n\rCHROMOSOME_20\x10\x14\x12\x11\n\rCHROMOSOME_21\x10\x15\x12\x11\n\rCHROMOSOME_22\x10\x16\x12\x10\n\x0c\x43HROMOSOME_X\x10\x17\x12\x10\n\x0c\x43HROMOSOME_Y\x10\x18\x12\x11\n\rCHROMOSOME_MT\x10\x19\x12\x12\n\x0e\x43HROMOSOME_PAR\x10\x1a\x12\x11\n\rCHROMOSOME_UN\x10\x1b*\x84\x04\n\x0b\x43ommentType\x12\x1c\n\x18\x43OMMENT_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13\x43OMMENT_TYPE_PUBLIC\x10\x01\x12!\n\x1d\x43OMMENT_TYPE_CONVERTED_BY_NCB\x10\x02\x12&\n"COMMENT_TYPE_MISSING_FROM_ASSEMBLY\x10\x03\x12\x31\n-COMMENT_TYPE_GENOMIC_LOCATION_NOT_ESTABLISHED\x10\x04\x12;\n7COMMENT_TYPE_LOCATION_ON_GENOME_AND_PRODUCT_NOT_ALIGNED\x10\x05\x12!\n\x1d\x43OMMENT_TYPE_DELETION_COMMENT\x10\x06\x12\x1e\n\x1a\x43OMMENT_TYPE_MERGE_COMMENT\x10\x07\x12\x34\n0COMMENT_TYPE_ASSEMBLY_SPECIFIC_ALLELE_DEFINITION\x10\x08\x12\x38\n4COMMENT_TYPE_ALIGNMENT_GAP_MAKES_APPEAR_INCONSISTENT\x10\t\x12.\n*COMMENT_TYPE_EXPLANATION_OF_CLASSIFICATION\x10\n\x12 \n\x1c\x43OMMENT_TYPE_FLAGGED_COMMENT\x10\x0b*\x98\x02\n\x12NucleotideSequence\x12#\n\x1fNUCLEOTIDE_SEQUENCE_UNSPECIFIED\x10\x00\x12)\n%NUCLEOTIDE_SEQUENCE_GENOMIC_TOP_LEVEL\x10\x01\x12,\n(NUCLEOTIDE_SEQUENCE_GENOMIC_REF_SEQ_GENE\x10\x02\x12\x1f\n\x1bNUCLEOTIDE_SEQUENCE_GENOMIC\x10\x03\x12\x1e\n\x1aNUCLEOTIDE_SEQUENCE_CODING\x10\x04\x12"\n\x1eNUCLEOTIDE_SEQUENCE_NON_CODING\x10\x05\x12\x1f\n\x1bNUCLEOTIDE_SEQUENCE_PROTEIN\x10\x06*Q\n\x0fProteinSequence\x12 \n\x1cPROTEIN_SEQUENCE_UNSPECIFIED\x10\x00\x12\x1c\n\x18PROTEIN_SEQUENCE_PROTEIN\x10\x01*\xef\x01\n\x10PhenotypeSetType\x12"\n\x1ePHENOTYPE_SET_TYPE_UNSPECIFIED\x10\x00\x12\x1e\n\x1aPHENOTYPE_SET_TYPE_DISEASE\x10\x01\x12$\n PHENOTYPE_SET_TYPE_DRUG_RESPONSE\x10\x02\x12\x1e\n\x1aPHENOTYPE_SET_TYPE_FINDING\x10\x03\x12,\n(PHENOTYPE_SET_TYPE_PHENOTYPE_INSTRUCTION\x10\x04\x12#\n\x1fPHENOTYPE_SET_TYPE_TRAIT_CHOICE\x10\x05*\xa0\x01\n\rVariationType\x12\x1e\n\x1aVARIATION_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18VARIATION_TYPE_DIPLOTYPE\x10\x01\x12(\n$VARIATION_TYPE_COMPOUND_HETEROZYGOTE\x10\x02\x12\'\n#VARIATION_TYPE_DISTINCT_CHROMOSOMES\x10\x03*\xa7\x01\n\x0c\x45videnceType\x12\x1d\n\x19\x45VIDENCE_TYPE_UNSPECIFIED\x10\x00\x12\x19\n\x15\x45VIDENCE_TYPE_GENETIC\x10\x01\x12\x1e\n\x1a\x45VIDENCE_TYPE_EXPERIMENTAL\x10\x02\x12\x1c\n\x18\x45VIDENCE_TYPE_POPULATION\x10\x03\x12\x1f\n\x1b\x45VIDENCE_TYPE_COMPUTATIONAL\x10\x04*\xc0\x03\n\x0eMethodListType\x12 \n\x1cMETHOD_LIST_TYPE_UNSPECIFIED\x10\x00\x12$\n METHOD_LIST_TYPE_LITERATURE_ONLY\x10\x01\x12)\n%METHOD_LIST_TYPE_REFERENCE_POPULATION\x10\x02\x12!\n\x1dMETHOD_LIST_TYPE_CASE_CONTROL\x10\x03\x12%\n!METHOD_LIST_TYPE_CLINICAL_TESTING\x10\x04\x12\x1d\n\x19METHOD_LIST_TYPE_IN_VITRO\x10\x05\x12\x1c\n\x18METHOD_LIST_TYPE_IN_VIVO\x10\x06\x12\x1d\n\x19METHOD_LIST_TYPE_RESEARCH\x10\x07\x12\x1d\n\x19METHOD_LIST_TYPE_CURATION\x10\x08\x12!\n\x1dMETHOD_LIST_TYPE_NOT_PROVIDED\x10\t\x12,\n(METHOD_LIST_TYPE_PROVIDER_INTERPRETATION\x10\n\x12%\n!METHOD_LIST_TYPE_PHENOTYPING_ONLY\x10\x0b*\xa4\x01\n\x08HgvsType\x12\x19\n\x15HGVS_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10HGVS_TYPE_CODING\x10\x01\x12\x15\n\x11HGVS_TYPE_GENOMIC\x10\x02\x12\x1f\n\x1bHGVS_TYPE_GENOMIC_TOP_LEVEL\x10\x03\x12\x18\n\x14HGVS_TYPE_NON_CODING\x10\x04\x12\x15\n\x11HGVS_TYPE_PROTEIN\x10\x05*\xfa\x01\n"ClinicalFeaturesAffectedStatusType\x12\x36\n2CLINICAL_FEATURES_AFFECTED_STATUS_TYPE_UNSPECIFIED\x10\x00\x12\x32\n.CLINICAL_FEATURES_AFFECTED_STATUS_TYPE_PRESENT\x10\x01\x12\x31\n-CLINICAL_FEATURES_AFFECTED_STATUS_TYPE_ABSENT\x10\x02\x12\x35\n1CLINICAL_FEATURES_AFFECTED_STATUS_TYPE_NOT_TESTED\x10\x03*\x9b\x02\n\x12HaploVariationType\x12$\n HAPLO_VARIATION_TYPE_UNSPECIFIED\x10\x00\x12"\n\x1eHAPLO_VARIATION_TYPE_HAPLOTYPE\x10\x01\x12\x31\n-HAPLO_VARIATION_TYPE_HAPLOTYPE_SINGLE_VARIANT\x10\x02\x12"\n\x1eHAPLO_VARIATION_TYPE_VARIATION\x10\x03\x12&\n"HAPLO_VARIATION_TYPE_PHASE_UNKNOWN\x10\x04\x12<\n8HAPLO_VARIATION_TYPE_HAPLOTYPE_DEFINED_BY_SINGLE_VARIANT\x10\x05\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "clinvar_data.pbs.clinvar_public_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_GENEVARIANTRELATIONSHIP"]._serialized_start = 36055
    _globals["_GENEVARIANTRELATIONSHIP"]._serialized_end = 36505
    _globals["_SEVERITY"]._serialized_start = 36507
    _globals["_SEVERITY"]._serialized_end = 36606
    _globals["_STATUS"]._serialized_start = 36609
    _globals["_STATUS"]._serialized_end = 36855
    _globals["_SUBMITTERREVIEWSTATUS"]._serialized_start = 36858
    _globals["_SUBMITTERREVIEWSTATUS"]._serialized_end = 37649
    _globals["_ZYGOSITY"]._serialized_start = 37652
    _globals["_ZYGOSITY"]._serialized_end = 37835
    _globals["_ASSERTION"]._serialized_start = 37838
    _globals["_ASSERTION"]._serialized_end = 38119
    _globals["_AGGREGATEGERMLINEREVIEWSTATUS"]._serialized_start = 38122
    _globals["_AGGREGATEGERMLINEREVIEWSTATUS"]._serialized_end = 38862
    _globals["_AGGREGATESOMATICCLINICALIMPACTREVIEWSTATUS"]._serialized_start = 38865
    _globals["_AGGREGATESOMATICCLINICALIMPACTREVIEWSTATUS"]._serialized_end = 39656
    _globals["_AGGREGATEONCOGENICITYREVIEWSTATUS"]._serialized_start = 39659
    _globals["_AGGREGATEONCOGENICITYREVIEWSTATUS"]._serialized_end = 40443
    _globals["_ORIGIN"]._serialized_start = 40446
    _globals["_ORIGIN"]._serialized_end = 40816
    _globals["_CHROMOSOME"]._serialized_start = 40819
    _globals["_CHROMOSOME"]._serialized_end = 41362
    _globals["_COMMENTTYPE"]._serialized_start = 41365
    _globals["_COMMENTTYPE"]._serialized_end = 41881
    _globals["_NUCLEOTIDESEQUENCE"]._serialized_start = 41884
    _globals["_NUCLEOTIDESEQUENCE"]._serialized_end = 42164
    _globals["_PROTEINSEQUENCE"]._serialized_start = 42166
    _globals["_PROTEINSEQUENCE"]._serialized_end = 42247
    _globals["_PHENOTYPESETTYPE"]._serialized_start = 42250
    _globals["_PHENOTYPESETTYPE"]._serialized_end = 42489
    _globals["_VARIATIONTYPE"]._serialized_start = 42492
    _globals["_VARIATIONTYPE"]._serialized_end = 42652
    _globals["_EVIDENCETYPE"]._serialized_start = 42655
    _globals["_EVIDENCETYPE"]._serialized_end = 42822
    _globals["_METHODLISTTYPE"]._serialized_start = 42825
    _globals["_METHODLISTTYPE"]._serialized_end = 43273
    _globals["_HGVSTYPE"]._serialized_start = 43276
    _globals["_HGVSTYPE"]._serialized_end = 43440
    _globals["_CLINICALFEATURESAFFECTEDSTATUSTYPE"]._serialized_start = 43443
    _globals["_CLINICALFEATURESAFFECTEDSTATUSTYPE"]._serialized_end = 43693
    _globals["_HAPLOVARIATIONTYPE"]._serialized_start = 43696
    _globals["_HAPLOVARIATIONTYPE"]._serialized_end = 43979
    _globals["_COMMENT"]._serialized_start = 108
    _globals["_COMMENT"]._serialized_end = 248
    _globals["_XREF"]._serialized_start = 251
    _globals["_XREF"]._serialized_end = 408
    _globals["_CITATION"]._serialized_start = 411
    _globals["_CITATION"]._serialized_end = 657
    _globals["_CITATION_IDTYPE"]._serialized_start = 572
    _globals["_CITATION_IDTYPE"]._serialized_end = 611
    _globals["_BASEATTRIBUTE"]._serialized_start = 660
    _globals["_BASEATTRIBUTE"]._serialized_end = 819
    _globals["_HGVSNUCLEOTIDEEXPRESSION"]._serialized_start = 822
    _globals["_HGVSNUCLEOTIDEEXPRESSION"]._serialized_end = 1351
    _globals["_HGVSPROTEINEXPRESSION"]._serialized_start = 1354
    _globals["_HGVSPROTEINEXPRESSION"]._serialized_end = 1609
    _globals["_HGVSEXPRESSION"]._serialized_start = 1612
    _globals["_HGVSEXPRESSION"]._serialized_end = 2025
    _globals["_SOFTWARE"]._serialized_start = 2027
    _globals["_SOFTWARE"]._serialized_end = 2119
    _globals["_DESCRIPTIONHISTORY"]._serialized_start = 2121
    _globals["_DESCRIPTIONHISTORY"]._serialized_end = 2220
    _globals["_GENERICSETELEMENT"]._serialized_start = 2223
    _globals["_GENERICSETELEMENT"]._serialized_end = 2447
    _globals["_ATTRIBUTESETELEMENT"]._serialized_start = 2450
    _globals["_ATTRIBUTESETELEMENT"]._serialized_end = 2819
    _globals["_ATTRIBUTESETELEMENT_ATTRIBUTE"]._serialized_start = 2732
    _globals["_ATTRIBUTESETELEMENT_ATTRIBUTE"]._serialized_end = 2819
    _globals["_TRAIT"]._serialized_start = 2822
    _globals["_TRAIT"]._serialized_end = 3845
    _globals["_TRAIT_TRAITRELATIONSHIP"]._serialized_start = 3322
    _globals["_TRAIT_TRAITRELATIONSHIP"]._serialized_end = 3845
    _globals["_TRAIT_TRAITRELATIONSHIP_TYPE"]._serialized_start = 3681
    _globals["_TRAIT_TRAITRELATIONSHIP_TYPE"]._serialized_end = 3845
    _globals["_INDICATION"]._serialized_start = 3848
    _globals["_INDICATION"]._serialized_end = 4348
    _globals["_INDICATION_TYPE"]._serialized_start = 4299
    _globals["_INDICATION_TYPE"]._serialized_end = 4348
    _globals["_TRAITSET"]._serialized_start = 4351
    _globals["_TRAITSET"]._serialized_end = 5365
    _globals["_TRAITSET_TYPE"]._serialized_start = 5084
    _globals["_TRAITSET_TYPE"]._serialized_end = 5227
    _globals["_AGGREGATEDGERMLINECLASSIFICATION"]._serialized_start = 5368
    _globals["_AGGREGATEDGERMLINECLASSIFICATION"]._serialized_end = 6250
    _globals["_AGGREGATEDSOMATICCLINICALIMPACT"]._serialized_start = 6253
    _globals["_AGGREGATEDSOMATICCLINICALIMPACT"]._serialized_end = 7063
    _globals["_AGGREGATEDONCOGENICITYCLASSIFICATION"]._serialized_start = 7066
    _globals["_AGGREGATEDONCOGENICITYCLASSIFICATION"]._serialized_end = 7872
    _globals["_AGGREGATECLASSIFICATIONSET"]._serialized_start = 7875
    _globals["_AGGREGATECLASSIFICATIONSET"]._serialized_end = 8313
    _globals["_CLINICALSIGNIFICANCE"]._serialized_start = 8316
    _globals["_CLINICALSIGNIFICANCE"]._serialized_end = 8828
    _globals["_ALLELEDESCRIPTION"]._serialized_start = 8831
    _globals["_ALLELEDESCRIPTION"]._serialized_end = 9350
    _globals["_ALLELEDESCRIPTION_RELATIVEORIENTATION"]._serialized_start = 9131
    _globals["_ALLELEDESCRIPTION_RELATIVEORIENTATION"]._serialized_end = 9286
    _globals["_RECORDHISTORY"]._serialized_start = 9353
    _globals["_RECORDHISTORY"]._serialized_end = 9574
    _globals["_CLASSIFICATIONSCV"]._serialized_start = 9577
    _globals["_CLASSIFICATIONSCV"]._serialized_end = 10759
    _globals["_CLASSIFICATIONSCV_SOMATICCLINICALIMPACT"]._serialized_start = 10255
    _globals["_CLASSIFICATIONSCV_SOMATICCLINICALIMPACT"]._serialized_end = 10547
    _globals["_CLASSIFICATIONSCV_CLASSIFICATIONSCORE"]._serialized_start = 10549
    _globals["_CLASSIFICATIONSCV_CLASSIFICATIONSCORE"]._serialized_end = 10613
    _globals["_SUBMITTERIDENTIFIERS"]._serialized_start = 10762
    _globals["_SUBMITTERIDENTIFIERS"]._serialized_end = 10898
    _globals["_SPECIES"]._serialized_start = 10900
    _globals["_SPECIES"]._serialized_end = 10965
    _globals["_CLASSIFIEDCONDITION"]._serialized_start = 10967
    _globals["_CLASSIFIEDCONDITION"]._serialized_end = 11051
    _globals["_CLINICALASSERTIONRECORDHISTORY"]._serialized_start = 11054
    _globals["_CLINICALASSERTIONRECORDHISTORY"]._serialized_end = 11265
    _globals["_FUNCTIONALCONSEQUENCE"]._serialized_start = 11268
    _globals["_FUNCTIONALCONSEQUENCE"]._serialized_end = 11482
    _globals["_GENERALCITATIONS"]._serialized_start = 11485
    _globals["_GENERALCITATIONS"]._serialized_end = 11619
    _globals["_COOCCURRENCE"]._serialized_start = 11622
    _globals["_COOCCURRENCE"]._serialized_end = 11826
    _globals["_SUBMITTER"]._serialized_start = 11829
    _globals["_SUBMITTER"]._serialized_end = 12074
    _globals["_SUBMITTER_TYPE"]._serialized_start = 11991
    _globals["_SUBMITTER_TYPE"]._serialized_end = 12074
    _globals["_DOSAGESENSITIVITY"]._serialized_start = 12077
    _globals["_DOSAGESENSITIVITY"]._serialized_end = 12221
    _globals["_OTHERNAME"]._serialized_start = 12223
    _globals["_OTHERNAME"]._serialized_end = 12277
    _globals["_DELETEDSCV"]._serialized_start = 12279
    _globals["_DELETEDSCV"]._serialized_end = 12377
    _globals["_LOCATION"]._serialized_start = 12380
    _globals["_LOCATION"]._serialized_end = 13787
    _globals["_LOCATION_SEQUENCELOCATION"]._serialized_start = 12590
    _globals["_LOCATION_SEQUENCELOCATION"]._serialized_end = 13787
    _globals["_LOCATION_SEQUENCELOCATION_ASSEMBLYSTATUS"]._serialized_start = 13320
    _globals["_LOCATION_SEQUENCELOCATION_ASSEMBLYSTATUS"]._serialized_end = 13428
    _globals["_SCV"]._serialized_start = 13789
    _globals["_SCV"]._serialized_end = 13860
    _globals["_FAMILYDATA"]._serialized_start = 13863
    _globals["_FAMILYDATA"]._serialized_end = 14235
    _globals["_SAMPLE"]._serialized_start = 14238
    _globals["_SAMPLE"]._serialized_end = 17086
    _globals["_SAMPLE_SAMPLEDESCRIPTION"]._serialized_start = 15498
    _globals["_SAMPLE_SAMPLEDESCRIPTION"]._serialized_end = 15680
    _globals["_SAMPLE_AGE"]._serialized_start = 15683
    _globals["_SAMPLE_AGE"]._serialized_end = 15829
    _globals["_SAMPLE_SOMATICVARIANTINNORMALTISSUE"]._serialized_start = 15832
    _globals["_SAMPLE_SOMATICVARIANTINNORMALTISSUE"]._serialized_end = 16052
    _globals["_SAMPLE_AGEUNIT"]._serialized_start = 16055
    _globals["_SAMPLE_AGEUNIT"]._serialized_end = 16231
    _globals["_SAMPLE_AGETYPE"]._serialized_start = 16233
    _globals["_SAMPLE_AGETYPE"]._serialized_end = 16333
    _globals["_SAMPLE_AFFECTEDSTATUS"]._serialized_start = 16336
    _globals["_SAMPLE_AFFECTEDSTATUS"]._serialized_end = 16533
    _globals["_SAMPLE_GENDER"]._serialized_start = 16535
    _globals["_SAMPLE_GENDER"]._serialized_end = 16621
    _globals["_SAMPLE_SOURCETYPE"]._serialized_start = 16623
    _globals["_SAMPLE_SOURCETYPE"]._serialized_end = 16730
    _globals["_METHOD"]._serialized_start = 17089
    _globals["_METHOD"]._serialized_end = 19114
    _globals["_METHOD_METHODATTRIBUTE"]._serialized_start = 17869
    _globals["_METHOD_METHODATTRIBUTE"]._serialized_end = 18301
    _globals["_METHOD_METHODATTRIBUTE_ATTRIBUTETYPE"]._serialized_start = 18036
    _globals["_METHOD_METHODATTRIBUTE_ATTRIBUTETYPE"]._serialized_end = 18301
    _globals["_METHOD_OBSMETHODATTRIBUTE"]._serialized_start = 18304
    _globals["_METHOD_OBSMETHODATTRIBUTE"]._serialized_end = 18656
    _globals["_METHOD_OBSMETHODATTRIBUTE_ATTRIBUTETYPE"]._serialized_start = 18536
    _globals["_METHOD_OBSMETHODATTRIBUTE_ATTRIBUTETYPE"]._serialized_end = 18656
    _globals["_METHOD_RESULTTYPE"]._serialized_start = 18659
    _globals["_METHOD_RESULTTYPE"]._serialized_end = 18822
    _globals["_METHOD_SOURCETYPE"]._serialized_start = 18825
    _globals["_METHOD_SOURCETYPE"]._serialized_end = 18961
    _globals["_ALLELESCV"]._serialized_start = 19117
    _globals["_ALLELESCV"]._serialized_end = 20493
    _globals["_ALLELESCV_GENE"]._serialized_start = 19896
    _globals["_ALLELESCV_GENE"]._serialized_end = 20148
    _globals["_ALLELESCV_MOLECULARCONSEQUENCE"]._serialized_start = 20151
    _globals["_ALLELESCV_MOLECULARCONSEQUENCE"]._serialized_end = 20449
    _globals["_HAPLOTYPESCV"]._serialized_start = 20496
    _globals["_HAPLOTYPESCV"]._serialized_end = 21279
    _globals["_GENOTYPESCV"]._serialized_start = 21282
    _globals["_GENOTYPESCV"]._serialized_end = 21978
    _globals["_OBSERVEDIN"]._serialized_start = 21981
    _globals["_OBSERVEDIN"]._serialized_end = 24129
    _globals["_OBSERVEDIN_OBSERVEDDATAATTRIBUTE"]._serialized_start = 22451
    _globals["_OBSERVEDIN_OBSERVEDDATAATTRIBUTE"]._serialized_end = 23462
    _globals["_OBSERVEDIN_OBSERVEDDATAATTRIBUTE_TYPE"]._serialized_start = 22625
    _globals["_OBSERVEDIN_OBSERVEDDATAATTRIBUTE_TYPE"]._serialized_end = 23462
    _globals["_OBSERVEDIN_OBSERVEDDATA"]._serialized_start = 23465
    _globals["_OBSERVEDIN_OBSERVEDDATA"]._serialized_end = 23821
    _globals["_OBSERVEDIN_METHODTYPE"]._serialized_start = 23824
    _globals["_OBSERVEDIN_METHODTYPE"]._serialized_end = 24115
    _globals["_CLINICALASSERTION"]._serialized_start = 24132
    _globals["_CLINICALASSERTION"]._serialized_end = 26905
    _globals["_CLINICALASSERTION_CLINVARSUBMISSIONID"]._serialized_start = 25609
    _globals["_CLINICALASSERTION_CLINVARSUBMISSIONID"]._serialized_end = 25799
    _globals["_CLINICALASSERTION_ATTRIBUTESETELEMENT"]._serialized_start = 25802
    _globals["_CLINICALASSERTION_ATTRIBUTESETELEMENT"]._serialized_end = 26372
    _globals["_CLINICALASSERTION_ATTRIBUTESETELEMENT_TYPE"]._serialized_start = 26160
    _globals["_CLINICALASSERTION_ATTRIBUTESETELEMENT_TYPE"]._serialized_end = 26372
    _globals["_CLINICALASSERTION_CLINVARACCESSION"]._serialized_start = 26375
    _globals["_CLINICALASSERTION_CLINVARACCESSION"]._serialized_end = 26659
    _globals["_CLINICALASSERTION_RECORDSTATUS"]._serialized_start = 26661
    _globals["_CLINICALASSERTION_RECORDSTATUS"]._serialized_end = 26788
    _globals["_ALLELE"]._serialized_start = 26908
    _globals["_ALLELE"]._serialized_end = 28684
    _globals["_ALLELE_GENE"]._serialized_start = 27805
    _globals["_ALLELE_GENE"]._serialized_end = 28352
    _globals["_ALLELE_ALLELEFREQUENCY"]._serialized_start = 28354
    _globals["_ALLELE_ALLELEFREQUENCY"]._serialized_end = 28428
    _globals["_ALLELE_GLOBALMINORALLELEFREQUENCY"]._serialized_start = 28431
    _globals["_ALLELE_GLOBALMINORALLELEFREQUENCY"]._serialized_end = 28560
    _globals["_ALLELE_NAME"]._serialized_start = 28562
    _globals["_ALLELE_NAME"]._serialized_end = 28611
    _globals["_HAPLOTYPE"]._serialized_start = 28687
    _globals["_HAPLOTYPE"]._serialized_end = 29444
    _globals["_INCLUDEDRECORD"]._serialized_start = 29447
    _globals["_INCLUDEDRECORD"]._serialized_end = 30094
    _globals["_INCLUDEDRECORD_CLASSIFIEDVARIATION"]._serialized_start = 29944
    _globals["_INCLUDEDRECORD_CLASSIFIEDVARIATION"]._serialized_end = 30042
    _globals["_GENOTYPE"]._serialized_start = 30097
    _globals["_GENOTYPE"]._serialized_end = 30956
    _globals["_RCVACCESSION"]._serialized_start = 30959
    _globals["_RCVACCESSION"]._serialized_end = 33297
    _globals["_RCVACCESSION_CLASSIFIEDCONDITIONLIST"]._serialized_start = 31305
    _globals["_RCVACCESSION_CLASSIFIEDCONDITIONLIST"]._serialized_end = 31459
    _globals["_RCVACCESSION_GERMLINECLASSIFICATION"]._serialized_start = 31462
    _globals["_RCVACCESSION_GERMLINECLASSIFICATION"]._serialized_end = 31845
    _globals["_RCVACCESSION_GERMLINECLASSIFICATION_DESCRIPTION"]._serialized_start = 31679
    _globals["_RCVACCESSION_GERMLINECLASSIFICATION_DESCRIPTION"]._serialized_end = 31845
    _globals["_RCVACCESSION_SOMATICCLINICALIMPACT"]._serialized_start = 31848
    _globals["_RCVACCESSION_SOMATICCLINICALIMPACT"]._serialized_end = 32417
    _globals["_RCVACCESSION_SOMATICCLINICALIMPACT_DESCRIPTION"]._serialized_start = 32077
    _globals["_RCVACCESSION_SOMATICCLINICALIMPACT_DESCRIPTION"]._serialized_end = 32417
    _globals["_RCVACCESSION_ONCOGENICITYCLASSIFICATION"]._serialized_start = 32420
    _globals["_RCVACCESSION_ONCOGENICITYCLASSIFICATION"]._serialized_end = 32815
    _globals["_RCVACCESSION_ONCOGENICITYCLASSIFICATION_DESCRIPTION"]._serialized_start = 31679
    _globals["_RCVACCESSION_ONCOGENICITYCLASSIFICATION_DESCRIPTION"]._serialized_end = 31845
    _globals["_RCVACCESSION_RCVCLASSIFICATIONS"]._serialized_start = 32818
    _globals["_RCVACCESSION_RCVCLASSIFICATIONS"]._serialized_end = 33257
    _globals["_CLASSIFIEDRECORD"]._serialized_start = 33300
    _globals["_CLASSIFIEDRECORD"]._serialized_end = 34659
    _globals["_CLASSIFIEDRECORD_RCVLIST"]._serialized_start = 34001
    _globals["_CLASSIFIEDRECORD_RCVLIST"]._serialized_end = 34201
    _globals["_CLASSIFIEDRECORD_TRAITMAPPING"]._serialized_start = 34204
    _globals["_CLASSIFIEDRECORD_TRAITMAPPING"]._serialized_end = 34523
    _globals["_CLASSIFIEDRECORD_TRAITMAPPING_MEDGEN"]._serialized_start = 34488
    _globals["_CLASSIFIEDRECORD_TRAITMAPPING_MEDGEN"]._serialized_end = 34523
    _globals["_CLASSIFIEDRECORD_MAPPINGTYPE"]._serialized_start = 34525
    _globals["_CLASSIFIEDRECORD_MAPPINGTYPE"]._serialized_end = 34614
    _globals["_VARIATIONARCHIVE"]._serialized_start = 34662
    _globals["_VARIATIONARCHIVE"]._serialized_end = 35895
    _globals["_VARIATIONARCHIVE_RECORDTYPE"]._serialized_start = 35600
    _globals["_VARIATIONARCHIVE_RECORDTYPE"]._serialized_end = 35695
    _globals["_VARIATIONARCHIVE_RECORDSTATUS"]._serialized_start = 35698
    _globals["_VARIATIONARCHIVE_RECORDSTATUS"]._serialized_end = 35853
    _globals["_CLINVARVARIATIONRELEASE"]._serialized_start = 35898
    _globals["_CLINVARVARIATIONRELEASE"]._serialized_end = 36052
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: clinvar_data/pbs/phenotype_link.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clinvar_data.pbs import (
    extracted_vars_pb2 as clinvar__data_dot_pbs_dot_extracted__vars__pb2,
)

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n%clinvar_data/pbs/phenotype_link.proto\x12\x1f\x63linvar_data.pbs.phenotype_link\x1a%clinvar_data/pbs/extracted_vars.proto"\xa0\x02\n\x13GenePhenotypeRecord\x12@\n\x03vcv\x18\x01 \x01(\x0b\x32\x33.clinvar_data.pbs.extracted_vars.VersionedAccession\x12@\n\x03scv\x18\x02 \x01(\x0b\x32\x33.clinvar_data.pbs.extracted_vars.VersionedAccession\x12\x1f\n\x17germline_classification\x18\x03 \x01(\t\x12\x16\n\x0esubmitter_name\x18\x04 \x01(\t\x12\x10\n\x08hgnc_ids\x18\x05 \x03(\t\x12\x12\n\nomim_terms\x18\x06 \x03(\t\x12\x13\n\x0bmondo_terms\x18\x07 \x03(\t\x12\x11\n\thpo_terms\x18\x08 \x03(\tb\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "clinvar_data.pbs.phenotype_link_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_GENEPHENOTYPERECORD"]._serialized_start = 114
    _globals["_GENEPHENOTYPERECORD"]._serialized_end = 402
# @@protoc_insertion_point(module_scope)



"""Extract variants from RCV records."""

import contextlib
import gzip
import json
import os
import typing

from google.protobuf.json_format import MessageToJson, ParseDict
import tqdm

from clinvar_data.pbs.clinvar_public import Allele, ClassifiedRecord, VariationArchive
from clinvar_data.pbs.clinvar_public_pb2 import (
    AggregateClassificationSet,
    ClinicalAssertion,
)
from clinvar_data.pbs.extracted_vars import (
    ExtractedRcvRecord,
    ExtractedVcvRecord,
    VariationType,
    VersionedAccession,
)


class OutputFilesHandler:
    """Helper for creating output paths."""

    def __init__(self, output_dir: str, gzip_output: bool):
        #: Output directory.
        self.output_dir = output_dir
        #: Whether to gzip output.
        self.gzip_output = gzip_output
        #: File suffix.
        self.suffix = "jsonl.gz" if self.gzip_output else "jsonl"
        #: Mapping of assembly and variant size to file.
        self.files: typing.Dict[typing.Tuple[str, str], typing.TextIO] = {}

    def get_file(self, stack: contextlib.ExitStack, assembly: str, variant_size: str):
        key = (assembly, variant_size)
        if key not in self.files:
            file_path = os.path.join(
                self.output_dir, f"clinvar-variants-{assembly}-{variant_size}.{self.suffix}"
            )
            if self.gzip_output:
                self.files[key] = gzip.open(file_path, "wt")
            else:
                self.files[key] = open(file_path, "wt")
            stack.push(self.files[key])
        return self.files[key]


class ConvertVariationType:
    """Static method helper for ``VariationType`` string to enum conversion."""

    #: Dict for conversion.
    CONVERT: dict[str, VariationType.ValueType] = {
        "insertion": VariationType.VARIATION_TYPE_INSERTION,
        "deletion": VariationType.VARIATION_TYPE_DELETION,
        "single nucleotide variant": VariationType.VARIATION_TYPE_SNV,
        "indel": VariationType.VARIATION_TYPE_INDEL,
        "duplication": VariationType.VARIATION_TYPE_DUPLICATION,
        "tandem duplication": VariationType.VARIATION_TYPE_TANDEM_DUPLICATION,
        "structural variant": VariationType.VARIATION_TYPE_STRUCTURAL_VARIANT,
        "copy number gain": VariationType.VARIATION_TYPE_COPY_NUMBER_GAIN,
        "copy number loss": VariationType.VARIATION_TYPE_COPY_NUMBER_LOSS,
        "protein only": VariationType.VARIATION_TYPE_PROTEIN_ONLY,
        "microsatellite": VariationType.VARIATION_TYPE_MICROSATELLITE,
        "inversion": VariationType.VARIATION_TYPE_INVERSION,
        "other": VariationType.VARIATION_TYPE_OTHER,
    }

    @classmethod
    def from_string_value(cls, string_value: str) -> VariationType.ValueType:
        """Convert string to protobuf enum value."""
        return cls.CONVERT.get(string_value.lower(), VariationType.VARIATION_TYPE_OTHER)


def thin_out_aggregate_classification_set(
    classifications: AggregateClassificationSet | None,
) -> AggregateClassificationSet | None:
    """Thin out the aggregate classifications set for extracted variants."""
    if classifications is None:
        return None
    else:
        result = AggregateClassificationSet()
        result.CopyFrom(classifications)
        if result.HasField("germline_classification"):
            for key in ("xrefs", "citations", "history_records", "conditions"):
                result.germline_classification.ClearField(key)
        if result.HasField("somatic_clinical_impact"):
            for key in ("xrefs", "citations", "history_records", "conditions"):
                result.somatic_clinical_impact.ClearField(key)
        if result.HasField("oncogenicity_classification"):
            for key in ("xrefs", "citations", "history_records", "conditions"):
                result.oncogenicity_classification.ClearField(key)
        return result


def thin_out_clinical_assertions(
    clinical_assertions: typing.Iterable[ClinicalAssertion],
) -> list[ClinicalAssertion]:
    result = []
    for clinical_assertion in clinical_assertions:
        entry = ClinicalAssertion()
        entry.CopyFrom(clinical_assertion)
        for key in (
            "clinvar_submission_id",
            "additional_submitters",
            "record_status",
            "attributes",
            "observed_ins",
            "simple_allele",
            "haplotype",
            "genotype",
            "trait_set",
            "citations",
            "study_name",
            "study_description",
            "comments",
            "submission_names",
            "date_created",
            "date_last_updated",
            "submission_date",
            "id",
            "fda_recognized_database",
        ):
            entry.ClearField(key)
        if entry.HasField("clinvar_accession"):
            entry.clinvar_accession.ClearField("submitter_identifiers")
        if entry.HasField("classifications"):
            entry.classifications.ClearField("comments")
        result.append(entry)
    return result


def run(path_input: str, output_dir: str, gzip_output: bool):
    """Execute the variant extraction."""
    os.makedirs(output_dir, exist_ok=True)

    if path_input.endswith(".gz"):
        inputf = gzip.open(path_input, "rt")
    else:
        inputf = open(path_input, "rt")

    output_files = OutputFilesHandler(output_dir, gzip_output)

    with inputf, contextlib.ExitStack() as stack:
        for line in tqdm.tqdm(inputf, desc="processing", unit=" JSONL records"):
            line_json = json.loads(line)
            variation_archive: VariationArchive = ParseDict(
                js_dict=line_json, message=VariationArchive()
            )

            if not variation_archive.HasField("classified_record"):
                continue
            classified_record: ClassifiedRecord = variation_archive.classified_record
            if not variation_archive.classified_record.HasField("simple_allele"):
                continue
            simple_allele: Allele = classified_record.simple_allele

            name: str = variation_archive.variation_name
            variation_type: VariationType.ValueType = ConvertVariationType.from_string_value(
                variation_archive.variation_type
            )
            accession: VersionedAccession = VersionedAccession(
                accession=variation_archive.accession,
                version=variation_archive.version,
            )
            rcvs: list[ExtractedRcvRecord] = [
                ExtractedRcvRecord(
                    accession=VersionedAccession(
                        accession=rcva.accession,
                        version=rcva.version,
                    ),
                    title=rcva.title,
                    classifications=rcva.rcv_classifications,
                )
                for rcva in classified_record.rcv_list.rcv_accessions
            ]
            hgnc_ids: list[str] = [
                gene.hgnc_id
                for gene in classified_record.simple_allele.genes
                if gene.HasField("hgnc_id")
            ]
            for location in simple_allele.locations or []:
                for sequence_location in location.sequence_locations or []:
                    record = ExtractedVcvRecord(
                        accession=accession,
                        rcvs=rcvs,
                        name=name,
                        variation_type=variation_type,
                        classifications=(
                            thin_out_aggregate_classification_set(classified_record.classifications)
                        ),
                        clinical_assertions=(
                            thin_out_clinical_assertions(classified_record.clinical_assertions)
                        ),
                        sequence_location=sequence_location,
                        hgnc_ids=hgnc_ids,
                    )

                    if record.variation_type == VariationType.VARIATION_TYPE_OTHER:
                        continue
                    if sequence_location.assembly.lower() == "ncbi36":
                        continue

                    if (
                        sequence_location.HasField("reference_allele")
                        and len(sequence_location.reference_allele) < 50
                        and sequence_location.HasField("alternate_allele")
                        and len(sequence_location.alternate_allele) < 50
                    ) or (
                        sequence_location.HasField("reference_allele_vcf")
                        and len(sequence_location.reference_allele_vcf) < 50
                        and sequence_location.HasField("alternate_allele_vcf")
                        and len(sequence_location.alternate_allele_vcf) < 50
                    ):
                        variant_size = "seqvars"
                    else:
                        variant_size = "strucvars"

                    dest = output_files.get_file(
                        stack, sequence_location.assembly.lower(), variant_size
                    )
                    print(MessageToJson(record, indent=None), file=dest)
